Module docs

Module docs 

This is a pseudo module which only exist for documentation purposes as a way to show the Slint documentation as part of rustdoc.

Modules

cargo_features
Feature flags and backend selection.
generated_code
This module exists only to explain the API of the code generated from .slint design markup. Its described structure is not really contained in the compiled crate.
mcu
type_mappings