SampleGlobal

Struct SampleGlobal 

pub struct SampleGlobal<'a> { /* private fields */ }
This an example of the API that is generated for a global in .slint design markup. This may help you understand what functions you can call and how you can pass data in and out.

This is the source code:

export global SampleGlobal {
    in-out property<int> value;
    // ... maybe more callbacks or public functions here
}

Note: Globals are only accessible in Rust if they are exported from the root file or the slint! macro!

Implementations

Source

impl<'a> SampleGlobal<'a>

pub fn get_value(&self) -> i32

A getter is generated for each property declared in the global. In this case, this is the getter that sets the value of the value property declared in the .slint design markup.

pub fn set_value(&self, value: i32)

A setter is generated for each property declared in the global. In this case, this is the setter that sets the value of the counter property declared in the .slint design markup.