pub enum SelectBundledTranslationError {
LanguageNotFound {
available_languages: SharedVector<SharedString>,
},
NoTranslationsBundled,
}Expand description
Error type returned from the select_bundled_translation function.
Variants
LanguageNotFound
The language was not found. The list of available languages is included in this error variant.
Fields

available_languages: SharedVector<SharedString>NoTranslationsBundled
There are no bundled translations. Either select_bundled_translation was called before creating a component,
or the application’s .slint file was compiled without the bundle translation option.