Struct DropEvent
#[non_exhaustive]#[repr(C)]pub struct DropEvent {
pub data: DataTransfer,
pub position: LogicalPosition,
pub allow_copy: bool,
pub allow_move: bool,
pub allow_link: bool,
pub proposed_action: DragAction,
}Expand description
This structure is passed to the callbacks of the DropArea element
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.data: DataTransferThe payload set on the source DragArea.
position: LogicalPositionThe cursor position in the DropArea’s local coordinates.
allow_copy: boolMirrors DragArea.allow-copy: true if the source allows the drop to copy the data.
allow_move: boolMirrors DragArea.allow-move: true if the source allows the drop to move the data.
allow_link: boolMirrors DragArea.allow-link: true if the source allows the drop to link to the data.
proposed_action: DragActionThe action negotiated from current modifier state, clamped to the allowed set;
when no modifier is pressed, the first allowed of move, copy, link.
Updated on every DragMove. The target’s can-drop callback can return this
to honor the user’s modifier choice, or override with any other allowed action.