Struct PointerEvent
#[non_exhaustive]#[repr(C)]pub struct PointerEvent {
pub button: PointerEventButton,
pub kind: PointerEventKind,
pub modifiers: KeyboardModifiers,
pub touch_finger_id: i32,
}Expand description
Represents a Pointer event sent by the windowing system.
This structure is passed to the pointer-event callback of the TouchArea element.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.The button that was pressed or released
kind: PointerEventKindThe kind of the event
modifiers: KeyboardModifiersThe keyboard modifiers pressed during the event
touch_finger_id: i32The unique ID of the touch point, indicating the finger ID. 0 means it’s not a touch event (e.g., mouse).