Struct SkiaWGPURenderer
pub struct SkiaWGPURenderer { /* private fields */ }unstable-wgpu-28 and (crate features renderer-skia or renderer-skia-opengl or renderer-skia-vulkan) only.Expand description
Use the Skia renderer with WGPU when implementing a custom Slint platform where you want the scene to be rendered into a WGPU texture. The rendering is done using the Skia library with platform-native GPU acceleration.
This is the Skia equivalent of FemtoVGWGPURenderer, offering superior font rendering
quality through platform-native text rasterizers.
Rendering notifier callbacks registered via
Window::set_rendering_notifier()
will receive GraphicsAPI::WGPU28 with the
renderer’s instance, device, and queue.
Implementations
impl SkiaWGPURenderer
impl SkiaWGPURenderer
pub fn new(
instance: Instance,
adapter: Adapter,
device: Device,
queue: Queue,
) -> Result<SkiaWGPURenderer, PlatformError>
pub fn new( instance: Instance, adapter: Adapter, device: Device, queue: Queue, ) -> Result<SkiaWGPURenderer, PlatformError>
Creates a new SkiaWGPURenderer.
The instance, adapter, device and queue are the WGPU resources used for rendering.
The adapter is needed to determine the GPU backend and create the Skia graphics context.
The wgpu resources are also provided to rendering notifier callbacks via
GraphicsAPI::WGPU28.
pub fn render_to_texture(&self, texture: &Texture) -> Result<(), PlatformError>
pub fn render_to_texture(&self, texture: &Texture) -> Result<(), PlatformError>
Render the scene to the given texture.
The texture must have been created with RENDER_ATTACHMENT usage and have a supported
format. Supported formats depend on the GPU backend: Rgba8Unorm and Rgba8UnormSrgb
are supported on all backends; Bgra8Unorm is additionally supported on Metal and Vulkan.