Struct WindowKeyEvent
#[non_exhaustive]#[repr(C)]pub struct WindowKeyEvent {
pub event_type: WindowKeyEventType,
pub event: KeyEvent,
}Expand description
A platform key event delivered through WindowEvent::Key.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.event_type: WindowKeyEventTypeWhether the key was pressed or released.
event: KeyEventThe key event details.
Implementations
impl WindowKeyEvent
impl WindowKeyEvent
pub fn new(event_type: WindowKeyEventType, event: KeyEvent) -> WindowKeyEvent
pub fn new(event_type: WindowKeyEventType, event: KeyEvent) -> WindowKeyEvent
Construct a new WindowKeyEvent with the given type and key event
Note: The KeyEvent::modifiers are ignored when processing the event and are overwritten with the current modifier state tracked by the window!