Struct slint::platform::WindowProperties
source · pub struct WindowProperties<'a>(/* private fields */);Expand description
This struct contains getters that provide access to properties of the Window
element, and is used with WindowAdapter::update_window_properties.
Implementations
sourceimpl<'a> WindowProperties<'a>
impl<'a> WindowProperties<'a>
sourcepub fn title(&self) -> SharedString
pub fn title(&self) -> SharedString
Returns the Window’s title
sourcepub fn background(&self) -> Brush
pub fn background(&self) -> Brush
The background color or brush of the Window
sourcepub fn layout_constraints(&self) -> LayoutConstraints
pub fn layout_constraints(&self) -> LayoutConstraints
Returns the layout constraints of the window
sourcepub fn fullscreen(&self) -> bool
👎Deprecated: Please use is_fullscreen instead
pub fn fullscreen(&self) -> bool
is_fullscreen insteadReturns true if the window should be shown fullscreen; false otherwise.
sourcepub fn is_fullscreen(&self) -> bool
pub fn is_fullscreen(&self) -> bool
Returns true if the window should be shown fullscreen; false otherwise.
sourcepub fn is_maximized(&self) -> bool
pub fn is_maximized(&self) -> bool
true if the window is in a maximized state, otherwise false
sourcepub fn is_minimized(&self) -> bool
pub fn is_minimized(&self) -> bool
true if the window is in a minimized state, otherwise false