Trait Renderer
pub trait Renderer: RendererSealed { }Expand description
This trait represents a Renderer that can render a slint scene.
This trait is sealed, meaning that you are not expected to implement this trait yourself, but you should use the provided ones from Slint.