Struct Keys
pub struct Keys { /* private fields */ }Expand description
The Keys type is the Rust representation of Slint’s keys primitive type.
It can be created with the @keys macro in Slint and defines which key event(s) activate a KeyBinding.
See also the Slint documentation on Key Bindings.