pub struct ModelPeer<'a> { /* private fields */ }Expand description
Represent a handle to a view that listens to changes to a model.
One should normally not use this class directly, it is just
used internally by via ModelTracker::attach_peer and ModelNotify