Struct BindGroupLayoutFlags
pub struct BindGroupLayoutFlags(/* private fields */);unstable-wgpu-27 only.Expand description
Pipeline layout creation flags.
Implementations
impl BindGroupLayoutFlags
impl BindGroupLayoutFlags
pub const PARTIALLY_BOUND: BindGroupLayoutFlags
Available on crate feature wgpu-27 only.
pub const PARTIALLY_BOUND: BindGroupLayoutFlags
wgpu-27 only.Allows for bind group binding arrays to be shorter than the array in the BGL.
impl BindGroupLayoutFlags
impl BindGroupLayoutFlags
pub const fn empty() -> BindGroupLayoutFlags
Available on crate feature wgpu-27 only.
pub const fn empty() -> BindGroupLayoutFlags
wgpu-27 only.Get a flags value with all bits unset.
pub const fn all() -> BindGroupLayoutFlags
Available on crate feature wgpu-27 only.
pub const fn all() -> BindGroupLayoutFlags
wgpu-27 only.Get a flags value with all known bits set.
pub const fn bits(&self) -> u32
Available on crate feature wgpu-27 only.
pub const fn bits(&self) -> u32
wgpu-27 only.Get the underlying bits value.
The returned value is exactly the bits set in this flags value.
pub const fn from_bits(bits: u32) -> Option<BindGroupLayoutFlags>
Available on crate feature wgpu-27 only.
pub const fn from_bits(bits: u32) -> Option<BindGroupLayoutFlags>
wgpu-27 only.Convert from a bits value.
This method will return None if any unknown bits are set.
pub const fn from_bits_truncate(bits: u32) -> BindGroupLayoutFlags
Available on crate feature wgpu-27 only.
pub const fn from_bits_truncate(bits: u32) -> BindGroupLayoutFlags
wgpu-27 only.Convert from a bits value, unsetting any unknown bits.
pub const fn from_bits_retain(bits: u32) -> BindGroupLayoutFlags
Available on crate feature wgpu-27 only.
pub const fn from_bits_retain(bits: u32) -> BindGroupLayoutFlags
wgpu-27 only.Convert from a bits value exactly.
pub fn from_name(name: &str) -> Option<BindGroupLayoutFlags>
Available on crate feature wgpu-27 only.
pub fn from_name(name: &str) -> Option<BindGroupLayoutFlags>
wgpu-27 only.Get a flags value with the bits of a flag with the given name set.
This method will return None if name is empty or doesn’t
correspond to any named flag.
pub const fn is_empty(&self) -> bool
Available on crate feature wgpu-27 only.
pub const fn is_empty(&self) -> bool
wgpu-27 only.Whether all bits in self are unset.
pub const fn is_all(&self) -> bool
Available on crate feature wgpu-27 only.
pub const fn is_all(&self) -> bool
wgpu-27 only.Whether all known bits in this flags value are set.
pub const fn intersects(&self, other: BindGroupLayoutFlags) -> bool
Available on crate feature wgpu-27 only.
pub const fn intersects(&self, other: BindGroupLayoutFlags) -> bool
wgpu-27 only.Whether any set bits in other are also set in self.
pub const fn contains(&self, other: BindGroupLayoutFlags) -> bool
Available on crate feature wgpu-27 only.
pub const fn contains(&self, other: BindGroupLayoutFlags) -> bool
wgpu-27 only.Whether all set bits in other are also set in self.
pub fn insert(&mut self, other: BindGroupLayoutFlags)
Available on crate feature wgpu-27 only.
pub fn insert(&mut self, other: BindGroupLayoutFlags)
wgpu-27 only.The bitwise or (|) of the bits in self and other.
pub fn remove(&mut self, other: BindGroupLayoutFlags)
Available on crate feature wgpu-27 only.
pub fn remove(&mut self, other: BindGroupLayoutFlags)
wgpu-27 only.The intersection of self with the complement of other (&!).
This method is not equivalent to self & !other when other has unknown bits set.
remove won’t truncate other, but the ! operator will.
pub fn toggle(&mut self, other: BindGroupLayoutFlags)
Available on crate feature wgpu-27 only.
pub fn toggle(&mut self, other: BindGroupLayoutFlags)
wgpu-27 only.The bitwise exclusive-or (^) of the bits in self and other.
pub fn set(&mut self, other: BindGroupLayoutFlags, value: bool)
Available on crate feature wgpu-27 only.
pub fn set(&mut self, other: BindGroupLayoutFlags, value: bool)
wgpu-27 only.Call insert when value is true or remove when value is false.
pub const fn intersection(
self,
other: BindGroupLayoutFlags,
) -> BindGroupLayoutFlags
Available on crate feature wgpu-27 only.
pub const fn intersection( self, other: BindGroupLayoutFlags, ) -> BindGroupLayoutFlags
wgpu-27 only.The bitwise and (&) of the bits in self and other.
pub const fn union(self, other: BindGroupLayoutFlags) -> BindGroupLayoutFlags
Available on crate feature wgpu-27 only.
pub const fn union(self, other: BindGroupLayoutFlags) -> BindGroupLayoutFlags
wgpu-27 only.The bitwise or (|) of the bits in self and other.
pub const fn difference(
self,
other: BindGroupLayoutFlags,
) -> BindGroupLayoutFlags
Available on crate feature wgpu-27 only.
pub const fn difference( self, other: BindGroupLayoutFlags, ) -> BindGroupLayoutFlags
wgpu-27 only.The intersection of self with the complement of other (&!).
This method is not equivalent to self & !other when other has unknown bits set.
difference won’t truncate other, but the ! operator will.
pub const fn symmetric_difference(
self,
other: BindGroupLayoutFlags,
) -> BindGroupLayoutFlags
Available on crate feature wgpu-27 only.
pub const fn symmetric_difference( self, other: BindGroupLayoutFlags, ) -> BindGroupLayoutFlags
wgpu-27 only.The bitwise exclusive-or (^) of the bits in self and other.
pub const fn complement(self) -> BindGroupLayoutFlags
Available on crate feature wgpu-27 only.
pub const fn complement(self) -> BindGroupLayoutFlags
wgpu-27 only.The bitwise negation (!) of the bits in self, truncating the result.
impl BindGroupLayoutFlags
impl BindGroupLayoutFlags
pub const fn iter(&self) -> Iter<BindGroupLayoutFlags>
Available on crate feature wgpu-27 only.
pub const fn iter(&self) -> Iter<BindGroupLayoutFlags>
wgpu-27 only.Yield a set of contained flags values.
Each yielded flags value will correspond to a defined named flag. Any unknown bits will be yielded together as a final flags value.
pub const fn iter_names(&self) -> IterNames<BindGroupLayoutFlags>
Available on crate feature wgpu-27 only.
pub const fn iter_names(&self) -> IterNames<BindGroupLayoutFlags>
wgpu-27 only.Yield a set of contained named flags values.
This method is like iter, except only yields bits in contained named flags.
Any unknown bits, or bits not corresponding to a contained flag will not be yielded.