pub struct Texture { /* private fields */ }unstable-wgpu-27 only.Expand description
Handle to a texture on the GPU.
It can be created with Device::create_texture.
Corresponds to WebGPU GPUTexture.
Implementations
Sourceimpl Texture
impl Texture
Sourcepub unsafe fn as_hal<A>(
&self,
) -> Option<impl Deref<Target = <A as Api>::Texture>>where
A: Api,
Available on crate feature wgpu-27 and wgpu_core only.
pub unsafe fn as_hal<A>(
&self,
) -> Option<impl Deref<Target = <A as Api>::Texture>>where
A: Api,
wgpu-27 and wgpu_core only.Get the wgpu_hal texture from this Texture.
Find the Api struct corresponding to the active backend in wgpu_hal::api,
and pass that struct to the to the A type parameter.
Returns a guard that dereferences to the type of the hal backend
which implements A::Texture.
Types
The returned type depends on the backend:
hal::api::Vulkanuseshal::vulkan::Texturehal::api::Metaluseshal::metal::Texturehal::api::Dx12useshal::dx12::Texturehal::api::Glesuseshal::gles::Texture
Deadlocks
- The returned guard holds a read-lock on a device-local “destruction”
lock, which will cause all calls to
destroyto block until the guard is released.
Errors
This method will return None if:
- The texture is not from the backend specified by
A. - The texture is from the
webgpuorcustombackend. - The texture has had
Self::destroy()called on it.
Safety
- The returned resource must not be destroyed unless the guard is the last reference to it and it is not in use by the GPU. The guard and handle may be dropped at any time however.
- All the safety requirements of wgpu-hal must be upheld.
Sourcepub fn create_view(
&self,
desc: &TextureViewDescriptor<Option<&str>>,
) -> TextureView
Available on crate feature wgpu-27 only.
pub fn create_view( &self, desc: &TextureViewDescriptor<Option<&str>>, ) -> TextureView
wgpu-27 only.Creates a view of this texture, specifying an interpretation of its texels and possibly a subset of its layers and mip levels.
Texture views are needed to use a texture as a binding in a BindGroup
or as an attachment in a RenderPass.
Sourcepub fn destroy(&self)
Available on crate feature wgpu-27 only.
pub fn destroy(&self)
wgpu-27 only.Destroy the associated native resources as soon as possible.
Sourcepub fn as_image_copy(&self) -> TexelCopyTextureInfo<&Texture>
Available on crate feature wgpu-27 only.
pub fn as_image_copy(&self) -> TexelCopyTextureInfo<&Texture>
wgpu-27 only.Make an TexelCopyTextureInfo representing the whole texture.
Sourcepub fn size(&self) -> Extent3d
Available on crate feature wgpu-27 only.
pub fn size(&self) -> Extent3d
wgpu-27 only.Returns the size of this Texture.
This is always equal to the size that was specified when creating the texture.
Sourcepub fn width(&self) -> u32
Available on crate feature wgpu-27 only.
pub fn width(&self) -> u32
wgpu-27 only.Returns the width of this Texture.
This is always equal to the size.width that was specified when creating the texture.
Sourcepub fn height(&self) -> u32
Available on crate feature wgpu-27 only.
pub fn height(&self) -> u32
wgpu-27 only.Returns the height of this Texture.
This is always equal to the size.height that was specified when creating the texture.
Sourcepub fn depth_or_array_layers(&self) -> u32
Available on crate feature wgpu-27 only.
pub fn depth_or_array_layers(&self) -> u32
wgpu-27 only.Returns the depth or layer count of this Texture.
This is always equal to the size.depth_or_array_layers that was specified when creating the texture.
Sourcepub fn mip_level_count(&self) -> u32
Available on crate feature wgpu-27 only.
pub fn mip_level_count(&self) -> u32
wgpu-27 only.Returns the mip_level_count of this Texture.
This is always equal to the mip_level_count that was specified when creating the texture.
Sourcepub fn sample_count(&self) -> u32
Available on crate feature wgpu-27 only.
pub fn sample_count(&self) -> u32
wgpu-27 only.Returns the sample_count of this Texture.
This is always equal to the sample_count that was specified when creating the texture.
Sourcepub fn dimension(&self) -> TextureDimension
Available on crate feature wgpu-27 only.
pub fn dimension(&self) -> TextureDimension
wgpu-27 only.Returns the dimension of this Texture.
This is always equal to the dimension that was specified when creating the texture.
Sourcepub fn format(&self) -> TextureFormat
Available on crate feature wgpu-27 only.
pub fn format(&self) -> TextureFormat
wgpu-27 only.Returns the format of this Texture.
This is always equal to the format that was specified when creating the texture.
Sourcepub fn usage(&self) -> TextureUsages
Available on crate feature wgpu-27 only.
pub fn usage(&self) -> TextureUsages
wgpu-27 only.Returns the allowed usages of this Texture.
This is always equal to the usage that was specified when creating the texture.