wgpu_render_bundle_push_debug_group

Function wgpu_render_bundle_push_debug_group 

pub unsafe fn wgpu_render_bundle_push_debug_group(
    _bundle: &mut RenderBundleEncoder,
    _label: *const i8,
)
Available on crate feature unstable-wgpu-27 only.
Safety

This function is unsafe as there is no guarantee that the given label is a valid null-terminated string.