wgpu_render_bundle_set_push_constants

Function wgpu_render_bundle_set_push_constants 

pub unsafe fn wgpu_render_bundle_set_push_constants(
    pass: &mut RenderBundleEncoder,
    stages: ShaderStages,
    offset: u32,
    size_bytes: u32,
    data: *const u8,
)
Available on crate feature unstable-wgpu-27 only.
Safety

This function is unsafe as there is no guarantee that the given pointer is valid for data elements.