Struct Barrier
pub struct Barrier(/* private fields */);unstable-wgpu-27 only.Expand description
Memory barrier flags.
Implementations
impl Barrier
impl Barrier
pub const STORAGE: Barrier
Available on crate feature wgpu-27 only.
pub const STORAGE: Barrier
wgpu-27 only.Barrier affects all AddressSpace::Storage accesses.
pub const WORK_GROUP: Barrier
Available on crate feature wgpu-27 only.
pub const WORK_GROUP: Barrier
wgpu-27 only.Barrier affects all AddressSpace::WorkGroup accesses.
impl Barrier
impl Barrier
pub const fn empty() -> Barrier
Available on crate feature wgpu-27 only.
pub const fn empty() -> Barrier
wgpu-27 only.Get a flags value with all bits unset.
pub const fn all() -> Barrier
Available on crate feature wgpu-27 only.
pub const fn all() -> Barrier
wgpu-27 only.Get a flags value with all known bits set.
pub const fn bits(&self) -> u32
Available on crate feature wgpu-27 only.
pub const fn bits(&self) -> u32
wgpu-27 only.Get the underlying bits value.
The returned value is exactly the bits set in this flags value.
pub const fn from_bits(bits: u32) -> Option<Barrier>
Available on crate feature wgpu-27 only.
pub const fn from_bits(bits: u32) -> Option<Barrier>
wgpu-27 only.Convert from a bits value.
This method will return None if any unknown bits are set.
pub const fn from_bits_truncate(bits: u32) -> Barrier
Available on crate feature wgpu-27 only.
pub const fn from_bits_truncate(bits: u32) -> Barrier
wgpu-27 only.Convert from a bits value, unsetting any unknown bits.
pub const fn from_bits_retain(bits: u32) -> Barrier
Available on crate feature wgpu-27 only.
pub const fn from_bits_retain(bits: u32) -> Barrier
wgpu-27 only.Convert from a bits value exactly.
pub fn from_name(name: &str) -> Option<Barrier>
Available on crate feature wgpu-27 only.
pub fn from_name(name: &str) -> Option<Barrier>
wgpu-27 only.Get a flags value with the bits of a flag with the given name set.
This method will return None if name is empty or doesn’t
correspond to any named flag.
pub const fn is_empty(&self) -> bool
Available on crate feature wgpu-27 only.
pub const fn is_empty(&self) -> bool
wgpu-27 only.Whether all bits in self are unset.
pub const fn is_all(&self) -> bool
Available on crate feature wgpu-27 only.
pub const fn is_all(&self) -> bool
wgpu-27 only.Whether all known bits in this flags value are set.
pub const fn intersects(&self, other: Barrier) -> bool
Available on crate feature wgpu-27 only.
pub const fn intersects(&self, other: Barrier) -> bool
wgpu-27 only.Whether any set bits in other are also set in self.
pub const fn contains(&self, other: Barrier) -> bool
Available on crate feature wgpu-27 only.
pub const fn contains(&self, other: Barrier) -> bool
wgpu-27 only.Whether all set bits in other are also set in self.
pub fn insert(&mut self, other: Barrier)
Available on crate feature wgpu-27 only.
pub fn insert(&mut self, other: Barrier)
wgpu-27 only.The bitwise or (|) of the bits in self and other.
pub fn remove(&mut self, other: Barrier)
Available on crate feature wgpu-27 only.
pub fn remove(&mut self, other: Barrier)
wgpu-27 only.The intersection of self with the complement of other (&!).
This method is not equivalent to self & !other when other has unknown bits set.
remove won’t truncate other, but the ! operator will.
pub fn toggle(&mut self, other: Barrier)
Available on crate feature wgpu-27 only.
pub fn toggle(&mut self, other: Barrier)
wgpu-27 only.The bitwise exclusive-or (^) of the bits in self and other.
pub fn set(&mut self, other: Barrier, value: bool)
Available on crate feature wgpu-27 only.
pub fn set(&mut self, other: Barrier, value: bool)
wgpu-27 only.Call insert when value is true or remove when value is false.
pub const fn intersection(self, other: Barrier) -> Barrier
Available on crate feature wgpu-27 only.
pub const fn intersection(self, other: Barrier) -> Barrier
wgpu-27 only.The bitwise and (&) of the bits in self and other.
pub const fn union(self, other: Barrier) -> Barrier
Available on crate feature wgpu-27 only.
pub const fn union(self, other: Barrier) -> Barrier
wgpu-27 only.The bitwise or (|) of the bits in self and other.
pub const fn difference(self, other: Barrier) -> Barrier
Available on crate feature wgpu-27 only.
pub const fn difference(self, other: Barrier) -> Barrier
wgpu-27 only.The intersection of self with the complement of other (&!).
This method is not equivalent to self & !other when other has unknown bits set.
difference won’t truncate other, but the ! operator will.
pub const fn symmetric_difference(self, other: Barrier) -> Barrier
Available on crate feature wgpu-27 only.
pub const fn symmetric_difference(self, other: Barrier) -> Barrier
wgpu-27 only.The bitwise exclusive-or (^) of the bits in self and other.
pub const fn complement(self) -> Barrier
Available on crate feature wgpu-27 only.
pub const fn complement(self) -> Barrier
wgpu-27 only.The bitwise negation (!) of the bits in self, truncating the result.
impl Barrier
impl Barrier
pub const fn iter(&self) -> Iter<Barrier>
Available on crate feature wgpu-27 only.
pub const fn iter(&self) -> Iter<Barrier>
wgpu-27 only.Yield a set of contained flags values.
Each yielded flags value will correspond to a defined named flag. Any unknown bits will be yielded together as a final flags value.
pub const fn iter_names(&self) -> IterNames<Barrier>
Available on crate feature wgpu-27 only.
pub const fn iter_names(&self) -> IterNames<Barrier>
wgpu-27 only.Yield a set of contained named flags values.
This method is like iter, except only yields bits in contained named flags.
Any unknown bits, or bits not corresponding to a contained flag will not be yielded.