Struct ValidationFlags
pub struct ValidationFlags(/* private fields */);unstable-wgpu-27 only.Expand description
Validation flags.
If you are working with trusted shaders, then you may be able to save some time by skipping validation.
If you do not perform full validation, invalid shaders may
cause Naga to panic. If you do perform full validation and
Validator::validate returns Ok, then Naga promises that
code generation will either succeed or return an error; it
should never panic.
The default value for ValidationFlags is
ValidationFlags::all().
Implementations
impl ValidationFlags
impl ValidationFlags
pub const EXPRESSIONS: ValidationFlags
Available on crate feature wgpu-27 only.
pub const EXPRESSIONS: ValidationFlags
wgpu-27 only.Expressions.
pub const BLOCKS: ValidationFlags
Available on crate feature wgpu-27 only.
pub const BLOCKS: ValidationFlags
wgpu-27 only.Statements and blocks of them.
pub const CONTROL_FLOW_UNIFORMITY: ValidationFlags
Available on crate feature wgpu-27 only.
pub const CONTROL_FLOW_UNIFORMITY: ValidationFlags
wgpu-27 only.Uniformity of control flow for operations that require it.
pub const STRUCT_LAYOUTS: ValidationFlags
Available on crate feature wgpu-27 only.
pub const STRUCT_LAYOUTS: ValidationFlags
wgpu-27 only.Host-shareable structure layouts.
pub const CONSTANTS: ValidationFlags
Available on crate feature wgpu-27 only.
pub const CONSTANTS: ValidationFlags
wgpu-27 only.Constants.
pub const BINDINGS: ValidationFlags
Available on crate feature wgpu-27 only.
pub const BINDINGS: ValidationFlags
wgpu-27 only.Group, binding, and location attributes.
impl ValidationFlags
impl ValidationFlags
pub const fn empty() -> ValidationFlags
Available on crate feature wgpu-27 only.
pub const fn empty() -> ValidationFlags
wgpu-27 only.Get a flags value with all bits unset.
pub const fn all() -> ValidationFlags
Available on crate feature wgpu-27 only.
pub const fn all() -> ValidationFlags
wgpu-27 only.Get a flags value with all known bits set.
pub const fn bits(&self) -> u8
Available on crate feature wgpu-27 only.
pub const fn bits(&self) -> u8
wgpu-27 only.Get the underlying bits value.
The returned value is exactly the bits set in this flags value.
pub const fn from_bits(bits: u8) -> Option<ValidationFlags>
Available on crate feature wgpu-27 only.
pub const fn from_bits(bits: u8) -> Option<ValidationFlags>
wgpu-27 only.Convert from a bits value.
This method will return None if any unknown bits are set.
pub const fn from_bits_truncate(bits: u8) -> ValidationFlags
Available on crate feature wgpu-27 only.
pub const fn from_bits_truncate(bits: u8) -> ValidationFlags
wgpu-27 only.Convert from a bits value, unsetting any unknown bits.
pub const fn from_bits_retain(bits: u8) -> ValidationFlags
Available on crate feature wgpu-27 only.
pub const fn from_bits_retain(bits: u8) -> ValidationFlags
wgpu-27 only.Convert from a bits value exactly.
pub fn from_name(name: &str) -> Option<ValidationFlags>
Available on crate feature wgpu-27 only.
pub fn from_name(name: &str) -> Option<ValidationFlags>
wgpu-27 only.Get a flags value with the bits of a flag with the given name set.
This method will return None if name is empty or doesn’t
correspond to any named flag.
pub const fn is_empty(&self) -> bool
Available on crate feature wgpu-27 only.
pub const fn is_empty(&self) -> bool
wgpu-27 only.Whether all bits in self are unset.
pub const fn is_all(&self) -> bool
Available on crate feature wgpu-27 only.
pub const fn is_all(&self) -> bool
wgpu-27 only.Whether all known bits in this flags value are set.
pub const fn intersects(&self, other: ValidationFlags) -> bool
Available on crate feature wgpu-27 only.
pub const fn intersects(&self, other: ValidationFlags) -> bool
wgpu-27 only.Whether any set bits in other are also set in self.
pub const fn contains(&self, other: ValidationFlags) -> bool
Available on crate feature wgpu-27 only.
pub const fn contains(&self, other: ValidationFlags) -> bool
wgpu-27 only.Whether all set bits in other are also set in self.
pub fn insert(&mut self, other: ValidationFlags)
Available on crate feature wgpu-27 only.
pub fn insert(&mut self, other: ValidationFlags)
wgpu-27 only.The bitwise or (|) of the bits in self and other.
pub fn remove(&mut self, other: ValidationFlags)
Available on crate feature wgpu-27 only.
pub fn remove(&mut self, other: ValidationFlags)
wgpu-27 only.The intersection of self with the complement of other (&!).
This method is not equivalent to self & !other when other has unknown bits set.
remove won’t truncate other, but the ! operator will.
pub fn toggle(&mut self, other: ValidationFlags)
Available on crate feature wgpu-27 only.
pub fn toggle(&mut self, other: ValidationFlags)
wgpu-27 only.The bitwise exclusive-or (^) of the bits in self and other.
pub fn set(&mut self, other: ValidationFlags, value: bool)
Available on crate feature wgpu-27 only.
pub fn set(&mut self, other: ValidationFlags, value: bool)
wgpu-27 only.Call insert when value is true or remove when value is false.
pub const fn intersection(self, other: ValidationFlags) -> ValidationFlags
Available on crate feature wgpu-27 only.
pub const fn intersection(self, other: ValidationFlags) -> ValidationFlags
wgpu-27 only.The bitwise and (&) of the bits in self and other.
pub const fn union(self, other: ValidationFlags) -> ValidationFlags
Available on crate feature wgpu-27 only.
pub const fn union(self, other: ValidationFlags) -> ValidationFlags
wgpu-27 only.The bitwise or (|) of the bits in self and other.
pub const fn difference(self, other: ValidationFlags) -> ValidationFlags
Available on crate feature wgpu-27 only.
pub const fn difference(self, other: ValidationFlags) -> ValidationFlags
wgpu-27 only.The intersection of self with the complement of other (&!).
This method is not equivalent to self & !other when other has unknown bits set.
difference won’t truncate other, but the ! operator will.
pub const fn symmetric_difference(
self,
other: ValidationFlags,
) -> ValidationFlags
Available on crate feature wgpu-27 only.
pub const fn symmetric_difference( self, other: ValidationFlags, ) -> ValidationFlags
wgpu-27 only.The bitwise exclusive-or (^) of the bits in self and other.
pub const fn complement(self) -> ValidationFlags
Available on crate feature wgpu-27 only.
pub const fn complement(self) -> ValidationFlags
wgpu-27 only.The bitwise negation (!) of the bits in self, truncating the result.
impl ValidationFlags
impl ValidationFlags
pub const fn iter(&self) -> Iter<ValidationFlags>
Available on crate feature wgpu-27 only.
pub const fn iter(&self) -> Iter<ValidationFlags>
wgpu-27 only.Yield a set of contained flags values.
Each yielded flags value will correspond to a defined named flag. Any unknown bits will be yielded together as a final flags value.
pub const fn iter_names(&self) -> IterNames<ValidationFlags>
Available on crate feature wgpu-27 only.
pub const fn iter_names(&self) -> IterNames<ValidationFlags>
wgpu-27 only.Yield a set of contained named flags values.
This method is like iter, except only yields bits in contained named flags.
Any unknown bits, or bits not corresponding to a contained flag will not be yielded.