Struct TextureFormatCapabilities
pub struct TextureFormatCapabilities(/* private fields */);unstable-wgpu-28 only.Expand description
Texture format capability flags.
Implementations
impl TextureFormatCapabilities
impl TextureFormatCapabilities
pub const SAMPLED: TextureFormatCapabilities
Available on crate feature wgpu-28 only.
pub const SAMPLED: TextureFormatCapabilities
wgpu-28 only.Format can be sampled.
pub const SAMPLED_LINEAR: TextureFormatCapabilities
Available on crate feature wgpu-28 only.
pub const SAMPLED_LINEAR: TextureFormatCapabilities
wgpu-28 only.Format can be sampled with a linear sampler.
pub const SAMPLED_MINMAX: TextureFormatCapabilities
Available on crate feature wgpu-28 only.
pub const SAMPLED_MINMAX: TextureFormatCapabilities
wgpu-28 only.Format can be sampled with a min/max reduction sampler.
pub const STORAGE_READ_ONLY: TextureFormatCapabilities
Available on crate feature wgpu-28 only.
pub const STORAGE_READ_ONLY: TextureFormatCapabilities
wgpu-28 only.Format can be used as storage with read-only access.
pub const STORAGE_WRITE_ONLY: TextureFormatCapabilities
Available on crate feature wgpu-28 only.
pub const STORAGE_WRITE_ONLY: TextureFormatCapabilities
wgpu-28 only.Format can be used as storage with write-only access.
pub const STORAGE_READ_WRITE: TextureFormatCapabilities
Available on crate feature wgpu-28 only.
pub const STORAGE_READ_WRITE: TextureFormatCapabilities
wgpu-28 only.Format can be used as storage with both read and write access.
pub const STORAGE_ATOMIC: TextureFormatCapabilities
Available on crate feature wgpu-28 only.
pub const STORAGE_ATOMIC: TextureFormatCapabilities
wgpu-28 only.Format can be used as storage with atomics.
pub const COLOR_ATTACHMENT: TextureFormatCapabilities
Available on crate feature wgpu-28 only.
pub const COLOR_ATTACHMENT: TextureFormatCapabilities
wgpu-28 only.Format can be used as color and input attachment.
pub const COLOR_ATTACHMENT_BLEND: TextureFormatCapabilities
Available on crate feature wgpu-28 only.
pub const COLOR_ATTACHMENT_BLEND: TextureFormatCapabilities
wgpu-28 only.Format can be used as color (with blending) and input attachment.
pub const DEPTH_STENCIL_ATTACHMENT: TextureFormatCapabilities
Available on crate feature wgpu-28 only.
pub const DEPTH_STENCIL_ATTACHMENT: TextureFormatCapabilities
wgpu-28 only.Format can be used as depth-stencil and input attachment.
pub const MULTISAMPLE_X2: TextureFormatCapabilities
Available on crate feature wgpu-28 only.
pub const MULTISAMPLE_X2: TextureFormatCapabilities
wgpu-28 only.Format can be multisampled by x2.
pub const MULTISAMPLE_X4: TextureFormatCapabilities
Available on crate feature wgpu-28 only.
pub const MULTISAMPLE_X4: TextureFormatCapabilities
wgpu-28 only.Format can be multisampled by x4.
pub const MULTISAMPLE_X8: TextureFormatCapabilities
Available on crate feature wgpu-28 only.
pub const MULTISAMPLE_X8: TextureFormatCapabilities
wgpu-28 only.Format can be multisampled by x8.
pub const MULTISAMPLE_X16: TextureFormatCapabilities
Available on crate feature wgpu-28 only.
pub const MULTISAMPLE_X16: TextureFormatCapabilities
wgpu-28 only.Format can be multisampled by x16.
pub const MULTISAMPLE_RESOLVE: TextureFormatCapabilities
Available on crate feature wgpu-28 only.
pub const MULTISAMPLE_RESOLVE: TextureFormatCapabilities
wgpu-28 only.Format can be used for render pass resolve targets.
pub const COPY_SRC: TextureFormatCapabilities
Available on crate feature wgpu-28 only.
pub const COPY_SRC: TextureFormatCapabilities
wgpu-28 only.Format can be copied from.
pub const COPY_DST: TextureFormatCapabilities
Available on crate feature wgpu-28 only.
pub const COPY_DST: TextureFormatCapabilities
wgpu-28 only.Format can be copied to.
impl TextureFormatCapabilities
impl TextureFormatCapabilities
pub const fn empty() -> TextureFormatCapabilities
Available on crate feature wgpu-28 only.
pub const fn empty() -> TextureFormatCapabilities
wgpu-28 only.Get a flags value with all bits unset.
pub const fn all() -> TextureFormatCapabilities
Available on crate feature wgpu-28 only.
pub const fn all() -> TextureFormatCapabilities
wgpu-28 only.Get a flags value with all known bits set.
pub const fn bits(&self) -> u32
Available on crate feature wgpu-28 only.
pub const fn bits(&self) -> u32
wgpu-28 only.Get the underlying bits value.
The returned value is exactly the bits set in this flags value.
pub const fn from_bits(bits: u32) -> Option<TextureFormatCapabilities>
Available on crate feature wgpu-28 only.
pub const fn from_bits(bits: u32) -> Option<TextureFormatCapabilities>
wgpu-28 only.Convert from a bits value.
This method will return None if any unknown bits are set.
pub const fn from_bits_truncate(bits: u32) -> TextureFormatCapabilities
Available on crate feature wgpu-28 only.
pub const fn from_bits_truncate(bits: u32) -> TextureFormatCapabilities
wgpu-28 only.Convert from a bits value, unsetting any unknown bits.
pub const fn from_bits_retain(bits: u32) -> TextureFormatCapabilities
Available on crate feature wgpu-28 only.
pub const fn from_bits_retain(bits: u32) -> TextureFormatCapabilities
wgpu-28 only.Convert from a bits value exactly.
pub fn from_name(name: &str) -> Option<TextureFormatCapabilities>
Available on crate feature wgpu-28 only.
pub fn from_name(name: &str) -> Option<TextureFormatCapabilities>
wgpu-28 only.Get a flags value with the bits of a flag with the given name set.
This method will return None if name is empty or doesn’t
correspond to any named flag.
pub const fn is_empty(&self) -> bool
Available on crate feature wgpu-28 only.
pub const fn is_empty(&self) -> bool
wgpu-28 only.Whether all bits in self are unset.
pub const fn is_all(&self) -> bool
Available on crate feature wgpu-28 only.
pub const fn is_all(&self) -> bool
wgpu-28 only.Whether all known bits in this flags value are set.
pub const fn intersects(&self, other: TextureFormatCapabilities) -> bool
Available on crate feature wgpu-28 only.
pub const fn intersects(&self, other: TextureFormatCapabilities) -> bool
wgpu-28 only.Whether any set bits in other are also set in self.
pub const fn contains(&self, other: TextureFormatCapabilities) -> bool
Available on crate feature wgpu-28 only.
pub const fn contains(&self, other: TextureFormatCapabilities) -> bool
wgpu-28 only.Whether all set bits in other are also set in self.
pub fn insert(&mut self, other: TextureFormatCapabilities)
Available on crate feature wgpu-28 only.
pub fn insert(&mut self, other: TextureFormatCapabilities)
wgpu-28 only.The bitwise or (|) of the bits in self and other.
pub fn remove(&mut self, other: TextureFormatCapabilities)
Available on crate feature wgpu-28 only.
pub fn remove(&mut self, other: TextureFormatCapabilities)
wgpu-28 only.The intersection of self with the complement of other (&!).
This method is not equivalent to self & !other when other has unknown bits set.
remove won’t truncate other, but the ! operator will.
pub fn toggle(&mut self, other: TextureFormatCapabilities)
Available on crate feature wgpu-28 only.
pub fn toggle(&mut self, other: TextureFormatCapabilities)
wgpu-28 only.The bitwise exclusive-or (^) of the bits in self and other.
pub fn set(&mut self, other: TextureFormatCapabilities, value: bool)
Available on crate feature wgpu-28 only.
pub fn set(&mut self, other: TextureFormatCapabilities, value: bool)
wgpu-28 only.Call insert when value is true or remove when value is false.
pub const fn intersection(
self,
other: TextureFormatCapabilities,
) -> TextureFormatCapabilities
Available on crate feature wgpu-28 only.
pub const fn intersection( self, other: TextureFormatCapabilities, ) -> TextureFormatCapabilities
wgpu-28 only.The bitwise and (&) of the bits in self and other.
pub const fn union(
self,
other: TextureFormatCapabilities,
) -> TextureFormatCapabilities
Available on crate feature wgpu-28 only.
pub const fn union( self, other: TextureFormatCapabilities, ) -> TextureFormatCapabilities
wgpu-28 only.The bitwise or (|) of the bits in self and other.
pub const fn difference(
self,
other: TextureFormatCapabilities,
) -> TextureFormatCapabilities
Available on crate feature wgpu-28 only.
pub const fn difference( self, other: TextureFormatCapabilities, ) -> TextureFormatCapabilities
wgpu-28 only.The intersection of self with the complement of other (&!).
This method is not equivalent to self & !other when other has unknown bits set.
difference won’t truncate other, but the ! operator will.
pub const fn symmetric_difference(
self,
other: TextureFormatCapabilities,
) -> TextureFormatCapabilities
Available on crate feature wgpu-28 only.
pub const fn symmetric_difference( self, other: TextureFormatCapabilities, ) -> TextureFormatCapabilities
wgpu-28 only.The bitwise exclusive-or (^) of the bits in self and other.
pub const fn complement(self) -> TextureFormatCapabilities
Available on crate feature wgpu-28 only.
pub const fn complement(self) -> TextureFormatCapabilities
wgpu-28 only.The bitwise negation (!) of the bits in self, truncating the result.
impl TextureFormatCapabilities
impl TextureFormatCapabilities
pub const fn iter(&self) -> Iter<TextureFormatCapabilities>
Available on crate feature wgpu-28 only.
pub const fn iter(&self) -> Iter<TextureFormatCapabilities>
wgpu-28 only.Yield a set of contained flags values.
Each yielded flags value will correspond to a defined named flag. Any unknown bits will be yielded together as a final flags value.
pub const fn iter_names(&self) -> IterNames<TextureFormatCapabilities>
Available on crate feature wgpu-28 only.
pub const fn iter_names(&self) -> IterNames<TextureFormatCapabilities>
wgpu-28 only.Yield a set of contained named flags values.
This method is like iter, except only yields bits in contained named flags.
Any unknown bits, or bits not corresponding to a contained flag will not be yielded.