Struct PipelineStatisticsTypes
pub struct PipelineStatisticsTypes(/* private fields */);unstable-wgpu-28 only.Expand description
Flags for which pipeline data should be recorded in a query.
Used in QueryType.
The amount of values written when resolved depends on the amount of flags set. For example, if 3 flags are set, 3 64-bit values will be written per query.
The order they are written is the order they are declared
in these bitflags. For example, if you enabled CLIPPER_PRIMITIVES_OUT
and COMPUTE_SHADER_INVOCATIONS, it would write 16 bytes,
the first 8 bytes being the primitive out value, the last 8
bytes being the compute shader invocation count.
Implementations
impl PipelineStatisticsTypes
impl PipelineStatisticsTypes
pub const VERTEX_SHADER_INVOCATIONS: PipelineStatisticsTypes
Available on crate feature wgpu-28 only.
pub const VERTEX_SHADER_INVOCATIONS: PipelineStatisticsTypes
wgpu-28 only.Amount of times the vertex shader is ran. Accounts for the vertex cache when doing indexed rendering.
pub const CLIPPER_INVOCATIONS: PipelineStatisticsTypes
Available on crate feature wgpu-28 only.
pub const CLIPPER_INVOCATIONS: PipelineStatisticsTypes
wgpu-28 only.Amount of times the clipper is invoked. This is also the amount of triangles output by the vertex shader.
pub const CLIPPER_PRIMITIVES_OUT: PipelineStatisticsTypes
Available on crate feature wgpu-28 only.
pub const CLIPPER_PRIMITIVES_OUT: PipelineStatisticsTypes
wgpu-28 only.Amount of primitives that are not culled by the clipper. This is the amount of triangles that are actually on screen and will be rasterized and rendered.
pub const FRAGMENT_SHADER_INVOCATIONS: PipelineStatisticsTypes
Available on crate feature wgpu-28 only.
pub const FRAGMENT_SHADER_INVOCATIONS: PipelineStatisticsTypes
wgpu-28 only.Amount of times the fragment shader is ran. Accounts for fragment shaders running in 2x2 blocks in order to get derivatives.
pub const COMPUTE_SHADER_INVOCATIONS: PipelineStatisticsTypes
Available on crate feature wgpu-28 only.
pub const COMPUTE_SHADER_INVOCATIONS: PipelineStatisticsTypes
wgpu-28 only.Amount of times a compute shader is invoked. This will be equivalent to the dispatch count times the workgroup size.
impl PipelineStatisticsTypes
impl PipelineStatisticsTypes
pub const fn empty() -> PipelineStatisticsTypes
Available on crate feature wgpu-28 only.
pub const fn empty() -> PipelineStatisticsTypes
wgpu-28 only.Get a flags value with all bits unset.
pub const fn all() -> PipelineStatisticsTypes
Available on crate feature wgpu-28 only.
pub const fn all() -> PipelineStatisticsTypes
wgpu-28 only.Get a flags value with all known bits set.
pub const fn bits(&self) -> u8
Available on crate feature wgpu-28 only.
pub const fn bits(&self) -> u8
wgpu-28 only.Get the underlying bits value.
The returned value is exactly the bits set in this flags value.
pub const fn from_bits(bits: u8) -> Option<PipelineStatisticsTypes>
Available on crate feature wgpu-28 only.
pub const fn from_bits(bits: u8) -> Option<PipelineStatisticsTypes>
wgpu-28 only.Convert from a bits value.
This method will return None if any unknown bits are set.
pub const fn from_bits_truncate(bits: u8) -> PipelineStatisticsTypes
Available on crate feature wgpu-28 only.
pub const fn from_bits_truncate(bits: u8) -> PipelineStatisticsTypes
wgpu-28 only.Convert from a bits value, unsetting any unknown bits.
pub const fn from_bits_retain(bits: u8) -> PipelineStatisticsTypes
Available on crate feature wgpu-28 only.
pub const fn from_bits_retain(bits: u8) -> PipelineStatisticsTypes
wgpu-28 only.Convert from a bits value exactly.
pub fn from_name(name: &str) -> Option<PipelineStatisticsTypes>
Available on crate feature wgpu-28 only.
pub fn from_name(name: &str) -> Option<PipelineStatisticsTypes>
wgpu-28 only.Get a flags value with the bits of a flag with the given name set.
This method will return None if name is empty or doesn’t
correspond to any named flag.
pub const fn is_empty(&self) -> bool
Available on crate feature wgpu-28 only.
pub const fn is_empty(&self) -> bool
wgpu-28 only.Whether all bits in self are unset.
pub const fn is_all(&self) -> bool
Available on crate feature wgpu-28 only.
pub const fn is_all(&self) -> bool
wgpu-28 only.Whether all known bits in this flags value are set.
pub const fn intersects(&self, other: PipelineStatisticsTypes) -> bool
Available on crate feature wgpu-28 only.
pub const fn intersects(&self, other: PipelineStatisticsTypes) -> bool
wgpu-28 only.Whether any set bits in other are also set in self.
pub const fn contains(&self, other: PipelineStatisticsTypes) -> bool
Available on crate feature wgpu-28 only.
pub const fn contains(&self, other: PipelineStatisticsTypes) -> bool
wgpu-28 only.Whether all set bits in other are also set in self.
pub fn insert(&mut self, other: PipelineStatisticsTypes)
Available on crate feature wgpu-28 only.
pub fn insert(&mut self, other: PipelineStatisticsTypes)
wgpu-28 only.The bitwise or (|) of the bits in self and other.
pub fn remove(&mut self, other: PipelineStatisticsTypes)
Available on crate feature wgpu-28 only.
pub fn remove(&mut self, other: PipelineStatisticsTypes)
wgpu-28 only.The intersection of self with the complement of other (&!).
This method is not equivalent to self & !other when other has unknown bits set.
remove won’t truncate other, but the ! operator will.
pub fn toggle(&mut self, other: PipelineStatisticsTypes)
Available on crate feature wgpu-28 only.
pub fn toggle(&mut self, other: PipelineStatisticsTypes)
wgpu-28 only.The bitwise exclusive-or (^) of the bits in self and other.
pub fn set(&mut self, other: PipelineStatisticsTypes, value: bool)
Available on crate feature wgpu-28 only.
pub fn set(&mut self, other: PipelineStatisticsTypes, value: bool)
wgpu-28 only.Call insert when value is true or remove when value is false.
pub const fn intersection(
self,
other: PipelineStatisticsTypes,
) -> PipelineStatisticsTypes
Available on crate feature wgpu-28 only.
pub const fn intersection( self, other: PipelineStatisticsTypes, ) -> PipelineStatisticsTypes
wgpu-28 only.The bitwise and (&) of the bits in self and other.
pub const fn union(
self,
other: PipelineStatisticsTypes,
) -> PipelineStatisticsTypes
Available on crate feature wgpu-28 only.
pub const fn union( self, other: PipelineStatisticsTypes, ) -> PipelineStatisticsTypes
wgpu-28 only.The bitwise or (|) of the bits in self and other.
pub const fn difference(
self,
other: PipelineStatisticsTypes,
) -> PipelineStatisticsTypes
Available on crate feature wgpu-28 only.
pub const fn difference( self, other: PipelineStatisticsTypes, ) -> PipelineStatisticsTypes
wgpu-28 only.The intersection of self with the complement of other (&!).
This method is not equivalent to self & !other when other has unknown bits set.
difference won’t truncate other, but the ! operator will.
pub const fn symmetric_difference(
self,
other: PipelineStatisticsTypes,
) -> PipelineStatisticsTypes
Available on crate feature wgpu-28 only.
pub const fn symmetric_difference( self, other: PipelineStatisticsTypes, ) -> PipelineStatisticsTypes
wgpu-28 only.The bitwise exclusive-or (^) of the bits in self and other.
pub const fn complement(self) -> PipelineStatisticsTypes
Available on crate feature wgpu-28 only.
pub const fn complement(self) -> PipelineStatisticsTypes
wgpu-28 only.The bitwise negation (!) of the bits in self, truncating the result.
impl PipelineStatisticsTypes
impl PipelineStatisticsTypes
pub const fn iter(&self) -> Iter<PipelineStatisticsTypes>
Available on crate feature wgpu-28 only.
pub const fn iter(&self) -> Iter<PipelineStatisticsTypes>
wgpu-28 only.Yield a set of contained flags values.
Each yielded flags value will correspond to a defined named flag. Any unknown bits will be yielded together as a final flags value.
pub const fn iter_names(&self) -> IterNames<PipelineStatisticsTypes>
Available on crate feature wgpu-28 only.
pub const fn iter_names(&self) -> IterNames<PipelineStatisticsTypes>
wgpu-28 only.Yield a set of contained named flags values.
This method is like iter, except only yields bits in contained named flags.
Any unknown bits, or bits not corresponding to a contained flag will not be yielded.