Struct TextureFormatFeatureFlags
pub struct TextureFormatFeatureFlags(/* private fields */);unstable-wgpu-28 only.Expand description
Feature flags for a texture format.
Implementations
impl TextureFormatFeatureFlags
impl TextureFormatFeatureFlags
pub const FILTERABLE: TextureFormatFeatureFlags
Available on crate feature wgpu-28 only.
pub const FILTERABLE: TextureFormatFeatureFlags
wgpu-28 only.If not present, the texture can’t be sampled with a filtering sampler. This may overwrite TextureSampleType::Float.filterable
pub const MULTISAMPLE_X2: TextureFormatFeatureFlags
Available on crate feature wgpu-28 only.
pub const MULTISAMPLE_X2: TextureFormatFeatureFlags
wgpu-28 only.Allows [TextureDescriptor::sample_count] to be 2.
pub const MULTISAMPLE_X4: TextureFormatFeatureFlags
Available on crate feature wgpu-28 only.
pub const MULTISAMPLE_X4: TextureFormatFeatureFlags
wgpu-28 only.Allows [TextureDescriptor::sample_count] to be 4.
pub const MULTISAMPLE_X8: TextureFormatFeatureFlags
Available on crate feature wgpu-28 only.
pub const MULTISAMPLE_X8: TextureFormatFeatureFlags
wgpu-28 only.Allows [TextureDescriptor::sample_count] to be 8.
pub const MULTISAMPLE_X16: TextureFormatFeatureFlags
Available on crate feature wgpu-28 only.
pub const MULTISAMPLE_X16: TextureFormatFeatureFlags
wgpu-28 only.Allows [TextureDescriptor::sample_count] to be 16.
pub const MULTISAMPLE_RESOLVE: TextureFormatFeatureFlags
Available on crate feature wgpu-28 only.
pub const MULTISAMPLE_RESOLVE: TextureFormatFeatureFlags
wgpu-28 only.Allows a texture of this format to back a view passed as resolve_target
to a render pass for an automatic driver-implemented resolve.
pub const STORAGE_READ_ONLY: TextureFormatFeatureFlags
Available on crate feature wgpu-28 only.
pub const STORAGE_READ_ONLY: TextureFormatFeatureFlags
wgpu-28 only.When used as a STORAGE texture, then a texture with this format can be bound with
[StorageTextureAccess::ReadOnly].
pub const STORAGE_WRITE_ONLY: TextureFormatFeatureFlags
Available on crate feature wgpu-28 only.
pub const STORAGE_WRITE_ONLY: TextureFormatFeatureFlags
wgpu-28 only.When used as a STORAGE texture, then a texture with this format can be bound with
[StorageTextureAccess::WriteOnly].
pub const STORAGE_READ_WRITE: TextureFormatFeatureFlags
Available on crate feature wgpu-28 only.
pub const STORAGE_READ_WRITE: TextureFormatFeatureFlags
wgpu-28 only.When used as a STORAGE texture, then a texture with this format can be bound with
[StorageTextureAccess::ReadWrite].
pub const STORAGE_ATOMIC: TextureFormatFeatureFlags
Available on crate feature wgpu-28 only.
pub const STORAGE_ATOMIC: TextureFormatFeatureFlags
wgpu-28 only.When used as a STORAGE texture, then a texture with this format can be bound with
[StorageTextureAccess::Atomic].
pub const BLENDABLE: TextureFormatFeatureFlags
Available on crate feature wgpu-28 only.
pub const BLENDABLE: TextureFormatFeatureFlags
wgpu-28 only.If not present, the texture can’t be blended into the render target.
impl TextureFormatFeatureFlags
impl TextureFormatFeatureFlags
pub const fn empty() -> TextureFormatFeatureFlags
Available on crate feature wgpu-28 only.
pub const fn empty() -> TextureFormatFeatureFlags
wgpu-28 only.Get a flags value with all bits unset.
pub const fn all() -> TextureFormatFeatureFlags
Available on crate feature wgpu-28 only.
pub const fn all() -> TextureFormatFeatureFlags
wgpu-28 only.Get a flags value with all known bits set.
pub const fn bits(&self) -> u32
Available on crate feature wgpu-28 only.
pub const fn bits(&self) -> u32
wgpu-28 only.Get the underlying bits value.
The returned value is exactly the bits set in this flags value.
pub const fn from_bits(bits: u32) -> Option<TextureFormatFeatureFlags>
Available on crate feature wgpu-28 only.
pub const fn from_bits(bits: u32) -> Option<TextureFormatFeatureFlags>
wgpu-28 only.Convert from a bits value.
This method will return None if any unknown bits are set.
pub const fn from_bits_truncate(bits: u32) -> TextureFormatFeatureFlags
Available on crate feature wgpu-28 only.
pub const fn from_bits_truncate(bits: u32) -> TextureFormatFeatureFlags
wgpu-28 only.Convert from a bits value, unsetting any unknown bits.
pub const fn from_bits_retain(bits: u32) -> TextureFormatFeatureFlags
Available on crate feature wgpu-28 only.
pub const fn from_bits_retain(bits: u32) -> TextureFormatFeatureFlags
wgpu-28 only.Convert from a bits value exactly.
pub fn from_name(name: &str) -> Option<TextureFormatFeatureFlags>
Available on crate feature wgpu-28 only.
pub fn from_name(name: &str) -> Option<TextureFormatFeatureFlags>
wgpu-28 only.Get a flags value with the bits of a flag with the given name set.
This method will return None if name is empty or doesn’t
correspond to any named flag.
pub const fn is_empty(&self) -> bool
Available on crate feature wgpu-28 only.
pub const fn is_empty(&self) -> bool
wgpu-28 only.Whether all bits in self are unset.
pub const fn is_all(&self) -> bool
Available on crate feature wgpu-28 only.
pub const fn is_all(&self) -> bool
wgpu-28 only.Whether all known bits in this flags value are set.
pub const fn intersects(&self, other: TextureFormatFeatureFlags) -> bool
Available on crate feature wgpu-28 only.
pub const fn intersects(&self, other: TextureFormatFeatureFlags) -> bool
wgpu-28 only.Whether any set bits in other are also set in self.
pub const fn contains(&self, other: TextureFormatFeatureFlags) -> bool
Available on crate feature wgpu-28 only.
pub const fn contains(&self, other: TextureFormatFeatureFlags) -> bool
wgpu-28 only.Whether all set bits in other are also set in self.
pub fn insert(&mut self, other: TextureFormatFeatureFlags)
Available on crate feature wgpu-28 only.
pub fn insert(&mut self, other: TextureFormatFeatureFlags)
wgpu-28 only.The bitwise or (|) of the bits in self and other.
pub fn remove(&mut self, other: TextureFormatFeatureFlags)
Available on crate feature wgpu-28 only.
pub fn remove(&mut self, other: TextureFormatFeatureFlags)
wgpu-28 only.The intersection of self with the complement of other (&!).
This method is not equivalent to self & !other when other has unknown bits set.
remove won’t truncate other, but the ! operator will.
pub fn toggle(&mut self, other: TextureFormatFeatureFlags)
Available on crate feature wgpu-28 only.
pub fn toggle(&mut self, other: TextureFormatFeatureFlags)
wgpu-28 only.The bitwise exclusive-or (^) of the bits in self and other.
pub fn set(&mut self, other: TextureFormatFeatureFlags, value: bool)
Available on crate feature wgpu-28 only.
pub fn set(&mut self, other: TextureFormatFeatureFlags, value: bool)
wgpu-28 only.Call insert when value is true or remove when value is false.
pub const fn intersection(
self,
other: TextureFormatFeatureFlags,
) -> TextureFormatFeatureFlags
Available on crate feature wgpu-28 only.
pub const fn intersection( self, other: TextureFormatFeatureFlags, ) -> TextureFormatFeatureFlags
wgpu-28 only.The bitwise and (&) of the bits in self and other.
pub const fn union(
self,
other: TextureFormatFeatureFlags,
) -> TextureFormatFeatureFlags
Available on crate feature wgpu-28 only.
pub const fn union( self, other: TextureFormatFeatureFlags, ) -> TextureFormatFeatureFlags
wgpu-28 only.The bitwise or (|) of the bits in self and other.
pub const fn difference(
self,
other: TextureFormatFeatureFlags,
) -> TextureFormatFeatureFlags
Available on crate feature wgpu-28 only.
pub const fn difference( self, other: TextureFormatFeatureFlags, ) -> TextureFormatFeatureFlags
wgpu-28 only.The intersection of self with the complement of other (&!).
This method is not equivalent to self & !other when other has unknown bits set.
difference won’t truncate other, but the ! operator will.
pub const fn symmetric_difference(
self,
other: TextureFormatFeatureFlags,
) -> TextureFormatFeatureFlags
Available on crate feature wgpu-28 only.
pub const fn symmetric_difference( self, other: TextureFormatFeatureFlags, ) -> TextureFormatFeatureFlags
wgpu-28 only.The bitwise exclusive-or (^) of the bits in self and other.
pub const fn complement(self) -> TextureFormatFeatureFlags
Available on crate feature wgpu-28 only.
pub const fn complement(self) -> TextureFormatFeatureFlags
wgpu-28 only.The bitwise negation (!) of the bits in self, truncating the result.
impl TextureFormatFeatureFlags
impl TextureFormatFeatureFlags
pub const fn iter(&self) -> Iter<TextureFormatFeatureFlags>
Available on crate feature wgpu-28 only.
pub const fn iter(&self) -> Iter<TextureFormatFeatureFlags>
wgpu-28 only.Yield a set of contained flags values.
Each yielded flags value will correspond to a defined named flag. Any unknown bits will be yielded together as a final flags value.
pub const fn iter_names(&self) -> IterNames<TextureFormatFeatureFlags>
Available on crate feature wgpu-28 only.
pub const fn iter_names(&self) -> IterNames<TextureFormatFeatureFlags>
wgpu-28 only.Yield a set of contained named flags values.
This method is like iter, except only yields bits in contained named flags.
Any unknown bits, or bits not corresponding to a contained flag will not be yielded.
impl TextureFormatFeatureFlags
impl TextureFormatFeatureFlags
pub fn sample_count_supported(&self, count: u32) -> bool
Available on crate feature wgpu-28 only.
pub fn sample_count_supported(&self, count: u32) -> bool
wgpu-28 only.Sample count supported by a given texture format.
returns true if count is a supported sample count.
pub fn supported_sample_counts(&self) -> Vec<u32>
Available on crate feature wgpu-28 only.
pub fn supported_sample_counts(&self) -> Vec<u32>
wgpu-28 only.A Vec of supported sample counts.