Struct WriterFlags
pub struct WriterFlags(/* private fields */);unstable-wgpu-28 and glsl_out only.Expand description
Configuration flags for the Writer.
Implementations
impl WriterFlags
impl WriterFlags
pub const ADJUST_COORDINATE_SPACE: WriterFlags
Available on crate feature wgpu-28 only.
pub const ADJUST_COORDINATE_SPACE: WriterFlags
wgpu-28 only.Flip output Y and extend Z from (0, 1) to (-1, 1).
pub const TEXTURE_SHADOW_LOD: WriterFlags
Available on crate feature wgpu-28 only.
pub const TEXTURE_SHADOW_LOD: WriterFlags
wgpu-28 only.Supports GL_EXT_texture_shadow_lod on the host, which provides additional functions on shadows and arrays of shadows.
pub const DRAW_PARAMETERS: WriterFlags
Available on crate feature wgpu-28 only.
pub const DRAW_PARAMETERS: WriterFlags
wgpu-28 only.Supports ARB_shader_draw_parameters on the host, which provides
support for gl_BaseInstanceARB, gl_BaseVertexARB, gl_DrawIDARB, and gl_DrawID.
pub const INCLUDE_UNUSED_ITEMS: WriterFlags
Available on crate feature wgpu-28 only.
pub const INCLUDE_UNUSED_ITEMS: WriterFlags
wgpu-28 only.Include unused global variables, constants and functions. By default the output will exclude global variables that are not used in the specified entrypoint (including indirect use), all constant declarations, and functions that use excluded global variables.
pub const FORCE_POINT_SIZE: WriterFlags
Available on crate feature wgpu-28 only.
pub const FORCE_POINT_SIZE: WriterFlags
wgpu-28 only.Emit PointSize output builtin to vertex shaders, which is
required for drawing with PointList topology.
https://registry.khronos.org/OpenGL/specs/es/3.2/GLSL_ES_Specification_3.20.html#built-in-language-variables The variable gl_PointSize is intended for a shader to write the size of the point to be rasterized. It is measured in pixels. If gl_PointSize is not written to, its value is undefined in subsequent pipe stages.
impl WriterFlags
impl WriterFlags
pub const fn empty() -> WriterFlags
Available on crate feature wgpu-28 only.
pub const fn empty() -> WriterFlags
wgpu-28 only.Get a flags value with all bits unset.
pub const fn all() -> WriterFlags
Available on crate feature wgpu-28 only.
pub const fn all() -> WriterFlags
wgpu-28 only.Get a flags value with all known bits set.
pub const fn bits(&self) -> u32
Available on crate feature wgpu-28 only.
pub const fn bits(&self) -> u32
wgpu-28 only.Get the underlying bits value.
The returned value is exactly the bits set in this flags value.
pub const fn from_bits(bits: u32) -> Option<WriterFlags>
Available on crate feature wgpu-28 only.
pub const fn from_bits(bits: u32) -> Option<WriterFlags>
wgpu-28 only.Convert from a bits value.
This method will return None if any unknown bits are set.
pub const fn from_bits_truncate(bits: u32) -> WriterFlags
Available on crate feature wgpu-28 only.
pub const fn from_bits_truncate(bits: u32) -> WriterFlags
wgpu-28 only.Convert from a bits value, unsetting any unknown bits.
pub const fn from_bits_retain(bits: u32) -> WriterFlags
Available on crate feature wgpu-28 only.
pub const fn from_bits_retain(bits: u32) -> WriterFlags
wgpu-28 only.Convert from a bits value exactly.
pub fn from_name(name: &str) -> Option<WriterFlags>
Available on crate feature wgpu-28 only.
pub fn from_name(name: &str) -> Option<WriterFlags>
wgpu-28 only.Get a flags value with the bits of a flag with the given name set.
This method will return None if name is empty or doesn’t
correspond to any named flag.
pub const fn is_empty(&self) -> bool
Available on crate feature wgpu-28 only.
pub const fn is_empty(&self) -> bool
wgpu-28 only.Whether all bits in self are unset.
pub const fn is_all(&self) -> bool
Available on crate feature wgpu-28 only.
pub const fn is_all(&self) -> bool
wgpu-28 only.Whether all known bits in this flags value are set.
pub const fn intersects(&self, other: WriterFlags) -> bool
Available on crate feature wgpu-28 only.
pub const fn intersects(&self, other: WriterFlags) -> bool
wgpu-28 only.Whether any set bits in other are also set in self.
pub const fn contains(&self, other: WriterFlags) -> bool
Available on crate feature wgpu-28 only.
pub const fn contains(&self, other: WriterFlags) -> bool
wgpu-28 only.Whether all set bits in other are also set in self.
pub fn insert(&mut self, other: WriterFlags)
Available on crate feature wgpu-28 only.
pub fn insert(&mut self, other: WriterFlags)
wgpu-28 only.The bitwise or (|) of the bits in self and other.
pub fn remove(&mut self, other: WriterFlags)
Available on crate feature wgpu-28 only.
pub fn remove(&mut self, other: WriterFlags)
wgpu-28 only.The intersection of self with the complement of other (&!).
This method is not equivalent to self & !other when other has unknown bits set.
remove won’t truncate other, but the ! operator will.
pub fn toggle(&mut self, other: WriterFlags)
Available on crate feature wgpu-28 only.
pub fn toggle(&mut self, other: WriterFlags)
wgpu-28 only.The bitwise exclusive-or (^) of the bits in self and other.
pub fn set(&mut self, other: WriterFlags, value: bool)
Available on crate feature wgpu-28 only.
pub fn set(&mut self, other: WriterFlags, value: bool)
wgpu-28 only.Call insert when value is true or remove when value is false.
pub const fn intersection(self, other: WriterFlags) -> WriterFlags
Available on crate feature wgpu-28 only.
pub const fn intersection(self, other: WriterFlags) -> WriterFlags
wgpu-28 only.The bitwise and (&) of the bits in self and other.
pub const fn union(self, other: WriterFlags) -> WriterFlags
Available on crate feature wgpu-28 only.
pub const fn union(self, other: WriterFlags) -> WriterFlags
wgpu-28 only.The bitwise or (|) of the bits in self and other.
pub const fn difference(self, other: WriterFlags) -> WriterFlags
Available on crate feature wgpu-28 only.
pub const fn difference(self, other: WriterFlags) -> WriterFlags
wgpu-28 only.The intersection of self with the complement of other (&!).
This method is not equivalent to self & !other when other has unknown bits set.
difference won’t truncate other, but the ! operator will.
pub const fn symmetric_difference(self, other: WriterFlags) -> WriterFlags
Available on crate feature wgpu-28 only.
pub const fn symmetric_difference(self, other: WriterFlags) -> WriterFlags
wgpu-28 only.The bitwise exclusive-or (^) of the bits in self and other.
pub const fn complement(self) -> WriterFlags
Available on crate feature wgpu-28 only.
pub const fn complement(self) -> WriterFlags
wgpu-28 only.The bitwise negation (!) of the bits in self, truncating the result.
impl WriterFlags
impl WriterFlags
pub const fn iter(&self) -> Iter<WriterFlags>
Available on crate feature wgpu-28 only.
pub const fn iter(&self) -> Iter<WriterFlags>
wgpu-28 only.Yield a set of contained flags values.
Each yielded flags value will correspond to a defined named flag. Any unknown bits will be yielded together as a final flags value.
pub const fn iter_names(&self) -> IterNames<WriterFlags>
Available on crate feature wgpu-28 only.
pub const fn iter_names(&self) -> IterNames<WriterFlags>
wgpu-28 only.Yield a set of contained named flags values.
This method is like iter, except only yields bits in contained named flags.
Any unknown bits, or bits not corresponding to a contained flag will not be yielded.