Struct Capabilities
pub struct Capabilities(/* private fields */);unstable-wgpu-28 only.Expand description
Allowed IR capabilities.
Implementations
impl Capabilities
impl Capabilities
pub const IMMEDIATES: Capabilities
Available on crate feature wgpu-28 only.
pub const IMMEDIATES: Capabilities
wgpu-28 only.Support for AddressSpace::Immediate.
pub const FLOAT64: Capabilities
Available on crate feature wgpu-28 only.
pub const FLOAT64: Capabilities
wgpu-28 only.Float values with width = 8.
pub const PRIMITIVE_INDEX: Capabilities
Available on crate feature wgpu-28 only.
pub const PRIMITIVE_INDEX: Capabilities
wgpu-28 only.Support for BuiltIn::PrimitiveIndex.
pub const TEXTURE_AND_SAMPLER_BINDING_ARRAY: Capabilities
Available on crate feature wgpu-28 only.
pub const TEXTURE_AND_SAMPLER_BINDING_ARRAY: Capabilities
wgpu-28 only.Support for binding arrays of sampled textures and samplers.
pub const BUFFER_BINDING_ARRAY: Capabilities
Available on crate feature wgpu-28 only.
pub const BUFFER_BINDING_ARRAY: Capabilities
wgpu-28 only.Support for binding arrays of uniform buffers.
pub const STORAGE_TEXTURE_BINDING_ARRAY: Capabilities
Available on crate feature wgpu-28 only.
pub const STORAGE_TEXTURE_BINDING_ARRAY: Capabilities
wgpu-28 only.Support for binding arrays of storage textures.
pub const STORAGE_BUFFER_BINDING_ARRAY: Capabilities
Available on crate feature wgpu-28 only.
pub const STORAGE_BUFFER_BINDING_ARRAY: Capabilities
wgpu-28 only.Support for binding arrays of storage buffers.
pub const CLIP_DISTANCE: Capabilities
Available on crate feature wgpu-28 only.
pub const CLIP_DISTANCE: Capabilities
wgpu-28 only.Support for BuiltIn::ClipDistance.
pub const CULL_DISTANCE: Capabilities
Available on crate feature wgpu-28 only.
pub const CULL_DISTANCE: Capabilities
wgpu-28 only.Support for BuiltIn::CullDistance.
pub const STORAGE_TEXTURE_16BIT_NORM_FORMATS: Capabilities
Available on crate feature wgpu-28 only.
pub const STORAGE_TEXTURE_16BIT_NORM_FORMATS: Capabilities
wgpu-28 only.Support for 16-bit normalized storage texture formats.
pub const MULTIVIEW: Capabilities
Available on crate feature wgpu-28 only.
pub const MULTIVIEW: Capabilities
wgpu-28 only.Support for BuiltIn::ViewIndex.
pub const EARLY_DEPTH_TEST: Capabilities
Available on crate feature wgpu-28 only.
pub const EARLY_DEPTH_TEST: Capabilities
wgpu-28 only.Support for early_depth_test.
pub const MULTISAMPLED_SHADING: Capabilities
Available on crate feature wgpu-28 only.
pub const MULTISAMPLED_SHADING: Capabilities
wgpu-28 only.Support for BuiltIn::SampleIndex and Sampling::Sample.
pub const RAY_QUERY: Capabilities
Available on crate feature wgpu-28 only.
pub const RAY_QUERY: Capabilities
wgpu-28 only.Support for ray queries and acceleration structures.
pub const DUAL_SOURCE_BLENDING: Capabilities
Available on crate feature wgpu-28 only.
pub const DUAL_SOURCE_BLENDING: Capabilities
wgpu-28 only.Support for generating two sources for blending from fragment shaders.
pub const CUBE_ARRAY_TEXTURES: Capabilities
Available on crate feature wgpu-28 only.
pub const CUBE_ARRAY_TEXTURES: Capabilities
wgpu-28 only.Support for arrayed cube textures.
pub const SHADER_INT64: Capabilities
Available on crate feature wgpu-28 only.
pub const SHADER_INT64: Capabilities
wgpu-28 only.Support for 64-bit signed and unsigned integers.
pub const SUBGROUP: Capabilities
Available on crate feature wgpu-28 only.
pub const SUBGROUP: Capabilities
wgpu-28 only.Support for subgroup operations (except barriers) in fragment and compute shaders.
Subgroup operations in the vertex stage require
Capabilities::SUBGROUP_VERTEX_STAGE in addition to Capabilities::SUBGROUP.
(But note that create_validator automatically sets
Capabilities::SUBGROUP whenever Features::SUBGROUP_VERTEX is
available.)
Subgroup barriers require Capabilities::SUBGROUP_BARRIER in addition to
Capabilities::SUBGROUP.
pub const SUBGROUP_BARRIER: Capabilities
Available on crate feature wgpu-28 only.
pub const SUBGROUP_BARRIER: Capabilities
wgpu-28 only.Support for subgroup barriers in compute shaders.
Requires Capabilities::SUBGROUP. Without it, enables nothing.
pub const SUBGROUP_VERTEX_STAGE: Capabilities
Available on crate feature wgpu-28 only.
pub const SUBGROUP_VERTEX_STAGE: Capabilities
wgpu-28 only.Support for subgroup operations (not including barriers) in the vertex stage.
Without Capabilities::SUBGROUP, enables nothing. (But note that
create_validator automatically sets Capabilities::SUBGROUP
whenever Features::SUBGROUP_VERTEX is available.)
pub const SHADER_INT64_ATOMIC_MIN_MAX: Capabilities
Available on crate feature wgpu-28 only.
pub const SHADER_INT64_ATOMIC_MIN_MAX: Capabilities
wgpu-28 only.Support for AtomicFunction::Min and AtomicFunction::Max on
64-bit integers in the Storage address space, when the return
value is not used.
This is the only 64-bit atomic functionality available on Metal 3.1.
pub const SHADER_INT64_ATOMIC_ALL_OPS: Capabilities
Available on crate feature wgpu-28 only.
pub const SHADER_INT64_ATOMIC_ALL_OPS: Capabilities
wgpu-28 only.Support for all atomic operations on 64-bit integers.
pub const SHADER_FLOAT32_ATOMIC: Capabilities
Available on crate feature wgpu-28 only.
pub const SHADER_FLOAT32_ATOMIC: Capabilities
wgpu-28 only.Support for AtomicFunction::Add, AtomicFunction::Sub,
and AtomicFunction::Exchange { compare: None } on 32-bit floating-point numbers
in the Storage address space.
pub const TEXTURE_ATOMIC: Capabilities
Available on crate feature wgpu-28 only.
pub const TEXTURE_ATOMIC: Capabilities
wgpu-28 only.Support for atomic operations on images.
pub const TEXTURE_INT64_ATOMIC: Capabilities
Available on crate feature wgpu-28 only.
pub const TEXTURE_INT64_ATOMIC: Capabilities
wgpu-28 only.Support for atomic operations on 64-bit images.
pub const RAY_HIT_VERTEX_POSITION: Capabilities
Available on crate feature wgpu-28 only.
pub const RAY_HIT_VERTEX_POSITION: Capabilities
wgpu-28 only.Support for ray queries returning vertex position
pub const SHADER_FLOAT16: Capabilities
Available on crate feature wgpu-28 only.
pub const SHADER_FLOAT16: Capabilities
wgpu-28 only.Support for 16-bit floating-point types.
pub const TEXTURE_EXTERNAL: Capabilities
Available on crate feature wgpu-28 only.
pub const TEXTURE_EXTERNAL: Capabilities
wgpu-28 only.Support for [ImageClass::External]
pub const SHADER_FLOAT16_IN_FLOAT32: Capabilities
Available on crate feature wgpu-28 only.
pub const SHADER_FLOAT16_IN_FLOAT32: Capabilities
wgpu-28 only.Support for quantizeToF16, pack2x16float, and unpack2x16float, which store
f16-precision values in f32s.
pub const SHADER_BARYCENTRICS: Capabilities
Available on crate feature wgpu-28 only.
pub const SHADER_BARYCENTRICS: Capabilities
wgpu-28 only.Support for fragment shader barycentric coordinates.
pub const MESH_SHADER: Capabilities
Available on crate feature wgpu-28 only.
pub const MESH_SHADER: Capabilities
wgpu-28 only.Support for task shaders, mesh shaders, and per-primitive fragment inputs
pub const MESH_SHADER_POINT_TOPOLOGY: Capabilities
Available on crate feature wgpu-28 only.
pub const MESH_SHADER_POINT_TOPOLOGY: Capabilities
wgpu-28 only.Support for mesh shaders which output points.
pub const TEXTURE_AND_SAMPLER_BINDING_ARRAY_NON_UNIFORM_INDEXING: Capabilities
Available on crate feature wgpu-28 only.
pub const TEXTURE_AND_SAMPLER_BINDING_ARRAY_NON_UNIFORM_INDEXING: Capabilities
wgpu-28 only.Support for non-uniform indexing of binding arrays of sampled textures and samplers.
pub const BUFFER_BINDING_ARRAY_NON_UNIFORM_INDEXING: Capabilities
Available on crate feature wgpu-28 only.
pub const BUFFER_BINDING_ARRAY_NON_UNIFORM_INDEXING: Capabilities
wgpu-28 only.Support for non-uniform indexing of binding arrays of uniform buffers.
pub const STORAGE_TEXTURE_BINDING_ARRAY_NON_UNIFORM_INDEXING: Capabilities
Available on crate feature wgpu-28 only.
pub const STORAGE_TEXTURE_BINDING_ARRAY_NON_UNIFORM_INDEXING: Capabilities
wgpu-28 only.Support for non-uniform indexing of binding arrays of storage textures.
pub const STORAGE_BUFFER_BINDING_ARRAY_NON_UNIFORM_INDEXING: Capabilities
Available on crate feature wgpu-28 only.
pub const STORAGE_BUFFER_BINDING_ARRAY_NON_UNIFORM_INDEXING: Capabilities
wgpu-28 only.Support for non-uniform indexing of binding arrays of storage buffers.
impl Capabilities
impl Capabilities
pub const fn empty() -> Capabilities
Available on crate feature wgpu-28 only.
pub const fn empty() -> Capabilities
wgpu-28 only.Get a flags value with all bits unset.
pub const fn all() -> Capabilities
Available on crate feature wgpu-28 only.
pub const fn all() -> Capabilities
wgpu-28 only.Get a flags value with all known bits set.
pub const fn bits(&self) -> u64
Available on crate feature wgpu-28 only.
pub const fn bits(&self) -> u64
wgpu-28 only.Get the underlying bits value.
The returned value is exactly the bits set in this flags value.
pub const fn from_bits(bits: u64) -> Option<Capabilities>
Available on crate feature wgpu-28 only.
pub const fn from_bits(bits: u64) -> Option<Capabilities>
wgpu-28 only.Convert from a bits value.
This method will return None if any unknown bits are set.
pub const fn from_bits_truncate(bits: u64) -> Capabilities
Available on crate feature wgpu-28 only.
pub const fn from_bits_truncate(bits: u64) -> Capabilities
wgpu-28 only.Convert from a bits value, unsetting any unknown bits.
pub const fn from_bits_retain(bits: u64) -> Capabilities
Available on crate feature wgpu-28 only.
pub const fn from_bits_retain(bits: u64) -> Capabilities
wgpu-28 only.Convert from a bits value exactly.
pub fn from_name(name: &str) -> Option<Capabilities>
Available on crate feature wgpu-28 only.
pub fn from_name(name: &str) -> Option<Capabilities>
wgpu-28 only.Get a flags value with the bits of a flag with the given name set.
This method will return None if name is empty or doesn’t
correspond to any named flag.
pub const fn is_empty(&self) -> bool
Available on crate feature wgpu-28 only.
pub const fn is_empty(&self) -> bool
wgpu-28 only.Whether all bits in self are unset.
pub const fn is_all(&self) -> bool
Available on crate feature wgpu-28 only.
pub const fn is_all(&self) -> bool
wgpu-28 only.Whether all known bits in this flags value are set.
pub const fn intersects(&self, other: Capabilities) -> bool
Available on crate feature wgpu-28 only.
pub const fn intersects(&self, other: Capabilities) -> bool
wgpu-28 only.Whether any set bits in other are also set in self.
pub const fn contains(&self, other: Capabilities) -> bool
Available on crate feature wgpu-28 only.
pub const fn contains(&self, other: Capabilities) -> bool
wgpu-28 only.Whether all set bits in other are also set in self.
pub fn insert(&mut self, other: Capabilities)
Available on crate feature wgpu-28 only.
pub fn insert(&mut self, other: Capabilities)
wgpu-28 only.The bitwise or (|) of the bits in self and other.
pub fn remove(&mut self, other: Capabilities)
Available on crate feature wgpu-28 only.
pub fn remove(&mut self, other: Capabilities)
wgpu-28 only.The intersection of self with the complement of other (&!).
This method is not equivalent to self & !other when other has unknown bits set.
remove won’t truncate other, but the ! operator will.
pub fn toggle(&mut self, other: Capabilities)
Available on crate feature wgpu-28 only.
pub fn toggle(&mut self, other: Capabilities)
wgpu-28 only.The bitwise exclusive-or (^) of the bits in self and other.
pub fn set(&mut self, other: Capabilities, value: bool)
Available on crate feature wgpu-28 only.
pub fn set(&mut self, other: Capabilities, value: bool)
wgpu-28 only.Call insert when value is true or remove when value is false.
pub const fn intersection(self, other: Capabilities) -> Capabilities
Available on crate feature wgpu-28 only.
pub const fn intersection(self, other: Capabilities) -> Capabilities
wgpu-28 only.The bitwise and (&) of the bits in self and other.
pub const fn union(self, other: Capabilities) -> Capabilities
Available on crate feature wgpu-28 only.
pub const fn union(self, other: Capabilities) -> Capabilities
wgpu-28 only.The bitwise or (|) of the bits in self and other.
pub const fn difference(self, other: Capabilities) -> Capabilities
Available on crate feature wgpu-28 only.
pub const fn difference(self, other: Capabilities) -> Capabilities
wgpu-28 only.The intersection of self with the complement of other (&!).
This method is not equivalent to self & !other when other has unknown bits set.
difference won’t truncate other, but the ! operator will.
pub const fn symmetric_difference(self, other: Capabilities) -> Capabilities
Available on crate feature wgpu-28 only.
pub const fn symmetric_difference(self, other: Capabilities) -> Capabilities
wgpu-28 only.The bitwise exclusive-or (^) of the bits in self and other.
pub const fn complement(self) -> Capabilities
Available on crate feature wgpu-28 only.
pub const fn complement(self) -> Capabilities
wgpu-28 only.The bitwise negation (!) of the bits in self, truncating the result.
impl Capabilities
impl Capabilities
pub const fn iter(&self) -> Iter<Capabilities>
Available on crate feature wgpu-28 only.
pub const fn iter(&self) -> Iter<Capabilities>
wgpu-28 only.Yield a set of contained flags values.
Each yielded flags value will correspond to a defined named flag. Any unknown bits will be yielded together as a final flags value.
pub const fn iter_names(&self) -> IterNames<Capabilities>
Available on crate feature wgpu-28 only.
pub const fn iter_names(&self) -> IterNames<Capabilities>
wgpu-28 only.Yield a set of contained named flags values.
This method is like iter, except only yields bits in contained named flags.
Any unknown bits, or bits not corresponding to a contained flag will not be yielded.