PollType

Enum PollType 

pub enum PollType<T> {
    Wait {
        submission_index: Option<T>,
        timeout: Option<Duration>,
    },
    Poll,
}
Available on crate feature unstable-wgpu-28 only.
Passed to Device::poll to control how and if it should block.

Variants



Wait

On wgpu-core based backends, block until the given submission has completed execution, and any callbacks have been invoked.

On WebGPU, this has no effect. Callbacks are invoked from the window event loop.

Fields

submission_index: Option<T>

Submission index to wait for.

If not specified, will wait for the most recent submission at the time of the poll. By the time the method returns, more submissions may have taken place.

timeout: Option<Duration>

Max time to wait for the submission to complete.

If not specified, will wait indefinitely (or until an error is detected). If waiting for the GPU device takes this long or longer, the poll will return PollError::Timeout.



Poll

Check the device for a single time without blocking.

Implementations



impl<T> PollType<T>

pub const fn wait_indefinitely() -> PollType<T>

Available on crate feature wgpu-28 only.

Wait indefinitely until for the most recent submission to complete.

This is a convenience function that creates a Self::Wait variant with no timeout and no submission index.

pub fn is_wait(&self) -> bool

Available on crate feature wgpu-28 only.

This PollType represents a wait of some kind.

pub fn map_index<U, F>(self, func: F) -> PollType<U>
where F: FnOnce(T) -> U,

Available on crate feature wgpu-28 only.

Map on the wait index type.