Struct BufferUses
pub struct BufferUses(/* private fields */);unstable-wgpu-28 only.Expand description
Similar to BufferUsages, but used only for CommandEncoder::transition_resources.
Implementations
impl BufferUses
impl BufferUses
pub const MAP_READ: BufferUses
Available on crate feature wgpu-28 only.
pub const MAP_READ: BufferUses
wgpu-28 only.The argument to a read-only mapping.
pub const MAP_WRITE: BufferUses
Available on crate feature wgpu-28 only.
pub const MAP_WRITE: BufferUses
wgpu-28 only.The argument to a write-only mapping.
pub const COPY_SRC: BufferUses
Available on crate feature wgpu-28 only.
pub const COPY_SRC: BufferUses
wgpu-28 only.The source of a hardware copy. cbindgen:ignore
pub const COPY_DST: BufferUses
Available on crate feature wgpu-28 only.
pub const COPY_DST: BufferUses
wgpu-28 only.The destination of a hardware copy. cbindgen:ignore
pub const INDEX: BufferUses
Available on crate feature wgpu-28 only.
pub const INDEX: BufferUses
wgpu-28 only.The index buffer used for drawing.
pub const VERTEX: BufferUses
Available on crate feature wgpu-28 only.
pub const VERTEX: BufferUses
wgpu-28 only.A vertex buffer used for drawing.
pub const UNIFORM: BufferUses
Available on crate feature wgpu-28 only.
pub const UNIFORM: BufferUses
wgpu-28 only.A uniform buffer bound in a bind group.
pub const STORAGE_READ_ONLY: BufferUses
Available on crate feature wgpu-28 only.
pub const STORAGE_READ_ONLY: BufferUses
wgpu-28 only.A read-only storage buffer used in a bind group. cbindgen:ignore
pub const STORAGE_READ_WRITE: BufferUses
Available on crate feature wgpu-28 only.
pub const STORAGE_READ_WRITE: BufferUses
wgpu-28 only.A read-write buffer used in a bind group. cbindgen:ignore
pub const INDIRECT: BufferUses
Available on crate feature wgpu-28 only.
pub const INDIRECT: BufferUses
wgpu-28 only.The indirect or count buffer in a indirect draw or dispatch.
pub const QUERY_RESOLVE: BufferUses
Available on crate feature wgpu-28 only.
pub const QUERY_RESOLVE: BufferUses
wgpu-28 only.A buffer used to store query results.
pub const ACCELERATION_STRUCTURE_SCRATCH: BufferUses
Available on crate feature wgpu-28 only.
pub const ACCELERATION_STRUCTURE_SCRATCH: BufferUses
wgpu-28 only.Buffer used for acceleration structure building.
pub const BOTTOM_LEVEL_ACCELERATION_STRUCTURE_INPUT: BufferUses
Available on crate feature wgpu-28 only.
pub const BOTTOM_LEVEL_ACCELERATION_STRUCTURE_INPUT: BufferUses
wgpu-28 only.Buffer used for bottom level acceleration structure building.
pub const TOP_LEVEL_ACCELERATION_STRUCTURE_INPUT: BufferUses
Available on crate feature wgpu-28 only.
pub const TOP_LEVEL_ACCELERATION_STRUCTURE_INPUT: BufferUses
wgpu-28 only.Buffer used for top level acceleration structure building.
pub const ACCELERATION_STRUCTURE_QUERY: BufferUses
Available on crate feature wgpu-28 only.
pub const ACCELERATION_STRUCTURE_QUERY: BufferUses
wgpu-28 only.A buffer used to store the compacted size of an acceleration structure
pub const INCLUSIVE: BufferUses
Available on crate feature wgpu-28 only.
pub const INCLUSIVE: BufferUses
wgpu-28 only.The combination of states that a buffer may be in at the same time.
pub const EXCLUSIVE: BufferUses
Available on crate feature wgpu-28 only.
pub const EXCLUSIVE: BufferUses
wgpu-28 only.The combination of states that a buffer must exclusively be in.
pub const ORDERED: BufferUses
Available on crate feature wgpu-28 only.
pub const ORDERED: BufferUses
wgpu-28 only.The combination of all usages that the are guaranteed to be be ordered by the hardware. If a usage is ordered, then if the buffer state doesn’t change between draw calls, there are no barriers needed for synchronization.
impl BufferUses
impl BufferUses
pub const fn empty() -> BufferUses
Available on crate feature wgpu-28 only.
pub const fn empty() -> BufferUses
wgpu-28 only.Get a flags value with all bits unset.
pub const fn all() -> BufferUses
Available on crate feature wgpu-28 only.
pub const fn all() -> BufferUses
wgpu-28 only.Get a flags value with all known bits set.
pub const fn bits(&self) -> u16
Available on crate feature wgpu-28 only.
pub const fn bits(&self) -> u16
wgpu-28 only.Get the underlying bits value.
The returned value is exactly the bits set in this flags value.
pub const fn from_bits(bits: u16) -> Option<BufferUses>
Available on crate feature wgpu-28 only.
pub const fn from_bits(bits: u16) -> Option<BufferUses>
wgpu-28 only.Convert from a bits value.
This method will return None if any unknown bits are set.
pub const fn from_bits_truncate(bits: u16) -> BufferUses
Available on crate feature wgpu-28 only.
pub const fn from_bits_truncate(bits: u16) -> BufferUses
wgpu-28 only.Convert from a bits value, unsetting any unknown bits.
pub const fn from_bits_retain(bits: u16) -> BufferUses
Available on crate feature wgpu-28 only.
pub const fn from_bits_retain(bits: u16) -> BufferUses
wgpu-28 only.Convert from a bits value exactly.
pub fn from_name(name: &str) -> Option<BufferUses>
Available on crate feature wgpu-28 only.
pub fn from_name(name: &str) -> Option<BufferUses>
wgpu-28 only.Get a flags value with the bits of a flag with the given name set.
This method will return None if name is empty or doesn’t
correspond to any named flag.
pub const fn is_empty(&self) -> bool
Available on crate feature wgpu-28 only.
pub const fn is_empty(&self) -> bool
wgpu-28 only.Whether all bits in self are unset.
pub const fn is_all(&self) -> bool
Available on crate feature wgpu-28 only.
pub const fn is_all(&self) -> bool
wgpu-28 only.Whether all known bits in this flags value are set.
pub const fn intersects(&self, other: BufferUses) -> bool
Available on crate feature wgpu-28 only.
pub const fn intersects(&self, other: BufferUses) -> bool
wgpu-28 only.Whether any set bits in other are also set in self.
pub const fn contains(&self, other: BufferUses) -> bool
Available on crate feature wgpu-28 only.
pub const fn contains(&self, other: BufferUses) -> bool
wgpu-28 only.Whether all set bits in other are also set in self.
pub fn insert(&mut self, other: BufferUses)
Available on crate feature wgpu-28 only.
pub fn insert(&mut self, other: BufferUses)
wgpu-28 only.The bitwise or (|) of the bits in self and other.
pub fn remove(&mut self, other: BufferUses)
Available on crate feature wgpu-28 only.
pub fn remove(&mut self, other: BufferUses)
wgpu-28 only.The intersection of self with the complement of other (&!).
This method is not equivalent to self & !other when other has unknown bits set.
remove won’t truncate other, but the ! operator will.
pub fn toggle(&mut self, other: BufferUses)
Available on crate feature wgpu-28 only.
pub fn toggle(&mut self, other: BufferUses)
wgpu-28 only.The bitwise exclusive-or (^) of the bits in self and other.
pub fn set(&mut self, other: BufferUses, value: bool)
Available on crate feature wgpu-28 only.
pub fn set(&mut self, other: BufferUses, value: bool)
wgpu-28 only.Call insert when value is true or remove when value is false.
pub const fn intersection(self, other: BufferUses) -> BufferUses
Available on crate feature wgpu-28 only.
pub const fn intersection(self, other: BufferUses) -> BufferUses
wgpu-28 only.The bitwise and (&) of the bits in self and other.
pub const fn union(self, other: BufferUses) -> BufferUses
Available on crate feature wgpu-28 only.
pub const fn union(self, other: BufferUses) -> BufferUses
wgpu-28 only.The bitwise or (|) of the bits in self and other.
pub const fn difference(self, other: BufferUses) -> BufferUses
Available on crate feature wgpu-28 only.
pub const fn difference(self, other: BufferUses) -> BufferUses
wgpu-28 only.The intersection of self with the complement of other (&!).
This method is not equivalent to self & !other when other has unknown bits set.
difference won’t truncate other, but the ! operator will.
pub const fn symmetric_difference(self, other: BufferUses) -> BufferUses
Available on crate feature wgpu-28 only.
pub const fn symmetric_difference(self, other: BufferUses) -> BufferUses
wgpu-28 only.The bitwise exclusive-or (^) of the bits in self and other.
pub const fn complement(self) -> BufferUses
Available on crate feature wgpu-28 only.
pub const fn complement(self) -> BufferUses
wgpu-28 only.The bitwise negation (!) of the bits in self, truncating the result.
impl BufferUses
impl BufferUses
pub const fn iter(&self) -> Iter<BufferUses>
Available on crate feature wgpu-28 only.
pub const fn iter(&self) -> Iter<BufferUses>
wgpu-28 only.Yield a set of contained flags values.
Each yielded flags value will correspond to a defined named flag. Any unknown bits will be yielded together as a final flags value.
pub const fn iter_names(&self) -> IterNames<BufferUses>
Available on crate feature wgpu-28 only.
pub const fn iter_names(&self) -> IterNames<BufferUses>
wgpu-28 only.Yield a set of contained named flags values.
This method is like iter, except only yields bits in contained named flags.
Any unknown bits, or bits not corresponding to a contained flag will not be yielded.