Struct ColorWrites
pub struct ColorWrites(/* private fields */);unstable-wgpu-28 only.Expand description
Color write mask. Disabled color channels will not be written to.
Corresponds to WebGPU GPUColorWriteFlags.
Implementations
impl ColorWrites
impl ColorWrites
pub const RED: ColorWrites
Available on crate feature wgpu-28 only.
pub const RED: ColorWrites
wgpu-28 only.Enable red channel writes
pub const GREEN: ColorWrites
Available on crate feature wgpu-28 only.
pub const GREEN: ColorWrites
wgpu-28 only.Enable green channel writes
pub const BLUE: ColorWrites
Available on crate feature wgpu-28 only.
pub const BLUE: ColorWrites
wgpu-28 only.Enable blue channel writes
pub const ALPHA: ColorWrites
Available on crate feature wgpu-28 only.
pub const ALPHA: ColorWrites
wgpu-28 only.Enable alpha channel writes
pub const COLOR: ColorWrites
Available on crate feature wgpu-28 only.
pub const COLOR: ColorWrites
wgpu-28 only.Enable red, green, and blue channel writes
pub const ALL: ColorWrites
Available on crate feature wgpu-28 only.
pub const ALL: ColorWrites
wgpu-28 only.Enable writes to all channels.
impl ColorWrites
impl ColorWrites
pub const fn empty() -> ColorWrites
Available on crate feature wgpu-28 only.
pub const fn empty() -> ColorWrites
wgpu-28 only.Get a flags value with all bits unset.
pub const fn all() -> ColorWrites
Available on crate feature wgpu-28 only.
pub const fn all() -> ColorWrites
wgpu-28 only.Get a flags value with all known bits set.
pub const fn bits(&self) -> u32
Available on crate feature wgpu-28 only.
pub const fn bits(&self) -> u32
wgpu-28 only.Get the underlying bits value.
The returned value is exactly the bits set in this flags value.
pub const fn from_bits(bits: u32) -> Option<ColorWrites>
Available on crate feature wgpu-28 only.
pub const fn from_bits(bits: u32) -> Option<ColorWrites>
wgpu-28 only.Convert from a bits value.
This method will return None if any unknown bits are set.
pub const fn from_bits_truncate(bits: u32) -> ColorWrites
Available on crate feature wgpu-28 only.
pub const fn from_bits_truncate(bits: u32) -> ColorWrites
wgpu-28 only.Convert from a bits value, unsetting any unknown bits.
pub const fn from_bits_retain(bits: u32) -> ColorWrites
Available on crate feature wgpu-28 only.
pub const fn from_bits_retain(bits: u32) -> ColorWrites
wgpu-28 only.Convert from a bits value exactly.
pub fn from_name(name: &str) -> Option<ColorWrites>
Available on crate feature wgpu-28 only.
pub fn from_name(name: &str) -> Option<ColorWrites>
wgpu-28 only.Get a flags value with the bits of a flag with the given name set.
This method will return None if name is empty or doesn’t
correspond to any named flag.
pub const fn is_empty(&self) -> bool
Available on crate feature wgpu-28 only.
pub const fn is_empty(&self) -> bool
wgpu-28 only.Whether all bits in self are unset.
pub const fn is_all(&self) -> bool
Available on crate feature wgpu-28 only.
pub const fn is_all(&self) -> bool
wgpu-28 only.Whether all known bits in this flags value are set.
pub const fn intersects(&self, other: ColorWrites) -> bool
Available on crate feature wgpu-28 only.
pub const fn intersects(&self, other: ColorWrites) -> bool
wgpu-28 only.Whether any set bits in other are also set in self.
pub const fn contains(&self, other: ColorWrites) -> bool
Available on crate feature wgpu-28 only.
pub const fn contains(&self, other: ColorWrites) -> bool
wgpu-28 only.Whether all set bits in other are also set in self.
pub fn insert(&mut self, other: ColorWrites)
Available on crate feature wgpu-28 only.
pub fn insert(&mut self, other: ColorWrites)
wgpu-28 only.The bitwise or (|) of the bits in self and other.
pub fn remove(&mut self, other: ColorWrites)
Available on crate feature wgpu-28 only.
pub fn remove(&mut self, other: ColorWrites)
wgpu-28 only.The intersection of self with the complement of other (&!).
This method is not equivalent to self & !other when other has unknown bits set.
remove won’t truncate other, but the ! operator will.
pub fn toggle(&mut self, other: ColorWrites)
Available on crate feature wgpu-28 only.
pub fn toggle(&mut self, other: ColorWrites)
wgpu-28 only.The bitwise exclusive-or (^) of the bits in self and other.
pub fn set(&mut self, other: ColorWrites, value: bool)
Available on crate feature wgpu-28 only.
pub fn set(&mut self, other: ColorWrites, value: bool)
wgpu-28 only.Call insert when value is true or remove when value is false.
pub const fn intersection(self, other: ColorWrites) -> ColorWrites
Available on crate feature wgpu-28 only.
pub const fn intersection(self, other: ColorWrites) -> ColorWrites
wgpu-28 only.The bitwise and (&) of the bits in self and other.
pub const fn union(self, other: ColorWrites) -> ColorWrites
Available on crate feature wgpu-28 only.
pub const fn union(self, other: ColorWrites) -> ColorWrites
wgpu-28 only.The bitwise or (|) of the bits in self and other.
pub const fn difference(self, other: ColorWrites) -> ColorWrites
Available on crate feature wgpu-28 only.
pub const fn difference(self, other: ColorWrites) -> ColorWrites
wgpu-28 only.The intersection of self with the complement of other (&!).
This method is not equivalent to self & !other when other has unknown bits set.
difference won’t truncate other, but the ! operator will.
pub const fn symmetric_difference(self, other: ColorWrites) -> ColorWrites
Available on crate feature wgpu-28 only.
pub const fn symmetric_difference(self, other: ColorWrites) -> ColorWrites
wgpu-28 only.The bitwise exclusive-or (^) of the bits in self and other.
pub const fn complement(self) -> ColorWrites
Available on crate feature wgpu-28 only.
pub const fn complement(self) -> ColorWrites
wgpu-28 only.The bitwise negation (!) of the bits in self, truncating the result.
impl ColorWrites
impl ColorWrites
pub const fn iter(&self) -> Iter<ColorWrites>
Available on crate feature wgpu-28 only.
pub const fn iter(&self) -> Iter<ColorWrites>
wgpu-28 only.Yield a set of contained flags values.
Each yielded flags value will correspond to a defined named flag. Any unknown bits will be yielded together as a final flags value.
pub const fn iter_names(&self) -> IterNames<ColorWrites>
Available on crate feature wgpu-28 only.
pub const fn iter_names(&self) -> IterNames<ColorWrites>
wgpu-28 only.Yield a set of contained named flags values.
This method is like iter, except only yields bits in contained named flags.
Any unknown bits, or bits not corresponding to a contained flag will not be yielded.