pub struct SurfaceTexture {
pub texture: Texture,
/* private fields */
}Available on crate feature
unstable-wgpu-29 only.Expand description
Surface texture that can be rendered to.
Result of a successful call to Surface::get_current_texture.
This type is unique to the Rust API of wgpu. In the WebGPU specification,
the GPUCanvasContext provides
a texture without any additional information.
Fields
texture: TextureAccessible view of the frame.
Implementations
Sourceimpl SurfaceTexture
impl SurfaceTexture
Sourcepub fn present(self)
Available on crate feature wgpu-29 only.
pub fn present(self)
wgpu-29 only.Schedule this texture to be presented on the owning surface.
Needs to be called after any work on the texture is scheduled via Queue::submit.
Platform dependent behavior
On Wayland, present will attach a wl_buffer to the underlying wl_surface and commit the new surface
state. If it is desired to do things such as request a frame callback, scale the surface using the viewporter
or synchronize other double buffered state, then these operations should be done before the call to present.