Struct TextureChannel
pub struct TextureChannel(/* private fields */);unstable-wgpu-29 only.Expand description
Represents the different format channels of a texture format.
Implementations
impl TextureChannel
impl TextureChannel
pub const RED: TextureChannel
Available on crate feature wgpu-29 only.
pub const RED: TextureChannel
wgpu-29 only.Texture format contains a red channel.
pub const GREEN: TextureChannel
Available on crate feature wgpu-29 only.
pub const GREEN: TextureChannel
wgpu-29 only.Texture format contains a green channel.
pub const BLUE: TextureChannel
Available on crate feature wgpu-29 only.
pub const BLUE: TextureChannel
wgpu-29 only.Texture format contains a blue channel.
pub const ALPHA: TextureChannel
Available on crate feature wgpu-29 only.
pub const ALPHA: TextureChannel
wgpu-29 only.Texture format contains an alpha channel.
pub const STENCIL: TextureChannel
Available on crate feature wgpu-29 only.
pub const STENCIL: TextureChannel
wgpu-29 only.Texture format contains a stencil channel.
pub const DEPTH: TextureChannel
Available on crate feature wgpu-29 only.
pub const DEPTH: TextureChannel
wgpu-29 only.Texture format contains a depth channel.
pub const LUMINANCE: TextureChannel
Available on crate feature wgpu-29 only.
pub const LUMINANCE: TextureChannel
wgpu-29 only.Texture format contains a luminance channel.
pub const CHROMINANCE_BLUE: TextureChannel
Available on crate feature wgpu-29 only.
pub const CHROMINANCE_BLUE: TextureChannel
wgpu-29 only.Texture format contains a blue-difference channel.
pub const CHROMINANCE_RED: TextureChannel
Available on crate feature wgpu-29 only.
pub const CHROMINANCE_RED: TextureChannel
wgpu-29 only.Texture format contains a red-difference channel.
pub const RG: TextureChannel
Available on crate feature wgpu-29 only.
pub const RG: TextureChannel
wgpu-29 only.Texture format contains channels for red and green.
pub const RGB: TextureChannel
Available on crate feature wgpu-29 only.
pub const RGB: TextureChannel
wgpu-29 only.Texture format contains channels for red, green and blue.
pub const RGBA: TextureChannel
Available on crate feature wgpu-29 only.
pub const RGBA: TextureChannel
wgpu-29 only.Texture format contains channels for red, green, blue and alpha.
pub const DEPTH_STENCIL: TextureChannel
Available on crate feature wgpu-29 only.
pub const DEPTH_STENCIL: TextureChannel
wgpu-29 only.Texture format contains channels for depth and stencil.
pub const LUMINANCE_CHROMINANCE: TextureChannel
Available on crate feature wgpu-29 only.
pub const LUMINANCE_CHROMINANCE: TextureChannel
wgpu-29 only.Texture format contains a luminance (Y), blue-difference (Cb) and red-difference (Cr) channel.
impl TextureChannel
impl TextureChannel
pub const fn empty() -> TextureChannel
Available on crate feature wgpu-29 only.
pub const fn empty() -> TextureChannel
wgpu-29 only.Get a flags value with all bits unset.
pub const fn all() -> TextureChannel
Available on crate feature wgpu-29 only.
pub const fn all() -> TextureChannel
wgpu-29 only.Get a flags value with all known bits set.
pub const fn bits(&self) -> u16
Available on crate feature wgpu-29 only.
pub const fn bits(&self) -> u16
wgpu-29 only.Get the underlying bits value.
The returned value is exactly the bits set in this flags value.
pub const fn from_bits(bits: u16) -> Option<TextureChannel>
Available on crate feature wgpu-29 only.
pub const fn from_bits(bits: u16) -> Option<TextureChannel>
wgpu-29 only.Convert from a bits value.
This method will return None if any unknown bits are set.
pub const fn from_bits_truncate(bits: u16) -> TextureChannel
Available on crate feature wgpu-29 only.
pub const fn from_bits_truncate(bits: u16) -> TextureChannel
wgpu-29 only.Convert from a bits value, unsetting any unknown bits.
pub const fn from_bits_retain(bits: u16) -> TextureChannel
Available on crate feature wgpu-29 only.
pub const fn from_bits_retain(bits: u16) -> TextureChannel
wgpu-29 only.Convert from a bits value exactly.
pub fn from_name(name: &str) -> Option<TextureChannel>
Available on crate feature wgpu-29 only.
pub fn from_name(name: &str) -> Option<TextureChannel>
wgpu-29 only.Get a flags value with the bits of a flag with the given name set.
This method will return None if name is empty or doesn’t
correspond to any named flag.
pub const fn is_empty(&self) -> bool
Available on crate feature wgpu-29 only.
pub const fn is_empty(&self) -> bool
wgpu-29 only.Whether all bits in self are unset.
pub const fn is_all(&self) -> bool
Available on crate feature wgpu-29 only.
pub const fn is_all(&self) -> bool
wgpu-29 only.Whether all known bits in this flags value are set.
pub const fn intersects(&self, other: TextureChannel) -> bool
Available on crate feature wgpu-29 only.
pub const fn intersects(&self, other: TextureChannel) -> bool
wgpu-29 only.Whether any set bits in other are also set in self.
pub const fn contains(&self, other: TextureChannel) -> bool
Available on crate feature wgpu-29 only.
pub const fn contains(&self, other: TextureChannel) -> bool
wgpu-29 only.Whether all set bits in other are also set in self.
pub fn insert(&mut self, other: TextureChannel)
Available on crate feature wgpu-29 only.
pub fn insert(&mut self, other: TextureChannel)
wgpu-29 only.The bitwise or (|) of the bits in self and other.
pub fn remove(&mut self, other: TextureChannel)
Available on crate feature wgpu-29 only.
pub fn remove(&mut self, other: TextureChannel)
wgpu-29 only.The intersection of self with the complement of other (&!).
This method is not equivalent to self & !other when other has unknown bits set.
remove won’t truncate other, but the ! operator will.
pub fn toggle(&mut self, other: TextureChannel)
Available on crate feature wgpu-29 only.
pub fn toggle(&mut self, other: TextureChannel)
wgpu-29 only.The bitwise exclusive-or (^) of the bits in self and other.
pub fn set(&mut self, other: TextureChannel, value: bool)
Available on crate feature wgpu-29 only.
pub fn set(&mut self, other: TextureChannel, value: bool)
wgpu-29 only.Call insert when value is true or remove when value is false.
pub const fn intersection(self, other: TextureChannel) -> TextureChannel
Available on crate feature wgpu-29 only.
pub const fn intersection(self, other: TextureChannel) -> TextureChannel
wgpu-29 only.The bitwise and (&) of the bits in self and other.
pub const fn union(self, other: TextureChannel) -> TextureChannel
Available on crate feature wgpu-29 only.
pub const fn union(self, other: TextureChannel) -> TextureChannel
wgpu-29 only.The bitwise or (|) of the bits in self and other.
pub const fn difference(self, other: TextureChannel) -> TextureChannel
Available on crate feature wgpu-29 only.
pub const fn difference(self, other: TextureChannel) -> TextureChannel
wgpu-29 only.The intersection of self with the complement of other (&!).
This method is not equivalent to self & !other when other has unknown bits set.
difference won’t truncate other, but the ! operator will.
pub const fn symmetric_difference(self, other: TextureChannel) -> TextureChannel
Available on crate feature wgpu-29 only.
pub const fn symmetric_difference(self, other: TextureChannel) -> TextureChannel
wgpu-29 only.The bitwise exclusive-or (^) of the bits in self and other.
pub const fn complement(self) -> TextureChannel
Available on crate feature wgpu-29 only.
pub const fn complement(self) -> TextureChannel
wgpu-29 only.The bitwise negation (!) of the bits in self, truncating the result.
impl TextureChannel
impl TextureChannel
pub const fn iter(&self) -> Iter<TextureChannel>
Available on crate feature wgpu-29 only.
pub const fn iter(&self) -> Iter<TextureChannel>
wgpu-29 only.Yield a set of contained flags values.
Each yielded flags value will correspond to a defined named flag. Any unknown bits will be yielded together as a final flags value.
pub const fn iter_names(&self) -> IterNames<TextureChannel>
Available on crate feature wgpu-29 only.
pub const fn iter_names(&self) -> IterNames<TextureChannel>
wgpu-29 only.Yield a set of contained named flags values.
This method is like iter, except only yields bits in contained named flags.
Any unknown bits, or bits not corresponding to a contained flag will not be yielded.