Struct ForceShaderModelToken
pub struct ForceShaderModelToken { /* private fields */ }Available on crate feature
unstable-wgpu-29 only.Expand description
Used to force wgpu to expose certain features on passthrough shaders even when those features aren’t present on runtime-compiled shaders
Implementations
impl ForceShaderModelToken
impl ForceShaderModelToken
pub unsafe fn with_shader_model(sm: DxcShaderModel) -> ForceShaderModelToken
Available on crate feature wgpu-29 only.
pub unsafe fn with_shader_model(sm: DxcShaderModel) -> ForceShaderModelToken
wgpu-29 only.Creates an unsafe token, opting you in to seeing features that you may not necessarily use on standard runtime-compiled shaders.
Safety
Do not make use in runtime-compiled shaders of any features that may not be supported by the FXC or DXC version you use.
pub fn get(&self) -> Option<DxcShaderModel>
Available on crate feature wgpu-29 only.
pub fn get(&self) -> Option<DxcShaderModel>
wgpu-29 only.Returns the shader model version, if any, in this token.