This is a pseudo module which only exist for documentation purposes as a way to show the Slint documentation as part of rustdoc.
- The
generated_codemodule contains an commented example of what is generated from the.slintfile
Modules
- cargo_
features - Feature flags and backend selection.
- generated_
code - This module exists only to explain the API of the code generated from
.slintdesign markup. Its described structure is not really contained in the compiled crate. - mcu
- type_
mappings