pub struct SampleGlobal<'a> { /* private fields */ }Expand description
This an example of the API that is generated for a global in .slint design markup. This may help you understand
what functions you can call and how you can pass data in and out.
This is the source code:
export global SampleGlobal {
in-out property<int> value;
// ... maybe more callbacks or public functions here
}Note: Globals are only accessible in Rust if they are exported from the root file or
the slint! macro!
Implementations