pub fn update_all_translations()Expand description
Forces all the strings that are translated with @tr(...) to be re-evaluated.
Call this function after changing the language at run-time and when translating
with either gettext or a custom translator. For bundled translations, there is no need
to call this function.