Enum AccessibleLiveness
#[non_exhaustive]#[repr(u32)]pub enum AccessibleLiveness {
Off = 0,
Polite = 1,
Assertive = 2,
}Expand description
This enum represents the different values of the accessible-live-region property.
It indicates that an element is a live region whose content changes should be
announced by assistive technologies.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
Off = 0
Use in regions that present information that is of low-importance to the user. Assistive technologies are expected to not announce changes unless the user explicitly asks for it.
Polite = 1
Use in regions that present new information to users. Assistive technologies are expected to not interrupt the user to inform of changes to the live region.
Assertive = 2
Use in regions that present information that a user should know about right away. Assistive technologies are expected to announce to the user as soon as possible.