Struct StyledText
pub struct StyledText { /* private fields */ }Expand description
Styled text that has been parsed and seperated into paragraphs
Implementations
impl StyledText
impl StyledText
pub fn from_plain_text(text: &str) -> StyledText
Available on crate feature std only.
pub fn from_plain_text(text: &str) -> StyledText
std only.Creates styled text from plain text without applying markdown parsing.
pub fn from_markdown(
markdown: &str,
) -> Result<StyledText, StyledTextFromMarkdownError>
Available on crate feature std only.
pub fn from_markdown( markdown: &str, ) -> Result<StyledText, StyledTextFromMarkdownError>
std only.Parses markdown into styled text.